// Code generated by 'make generate'; DO NOT EDIT.

package cmd

import (
	"fmt"
	"io"
	"sort"
	"strings"
	"text/tabwriter"
)

func allDNSCodes() string {
	providers := []string{
		"abion",
		"acmedns",
		"active24",
		"alidns",
		"aliesa",
		"allinkl",
		"alwaysdata",
		"anexia",
		"artfiles",
		"arvancloud",
		"auroradns",
		"autodns",
		"axelname",
		"azion",
		"azuredns",
		"baiducloud",
		"beget",
		"binarylane",
		"bindman",
		"bluecat",
		"bluecatv2",
		"bookmyname",
		"bunny",
		"checkdomain",
		"civo",
		"clouddns",
		"cloudflare",
		"cloudns",
		"cloudru",
		"com35",
		"connbyte",
		"conoha",
		"conohav3",
		"constellix",
		"corenetworks",
		"cpanel",
		"curanet",
		"czechia",
		"dandomain",
		"ddnss",
		"derak",
		"desec",
		"designate",
		"digitalocean",
		"dinahosting",
		"directadmin",
		"dns51",
		"dnscale",
		"dnsexit",
		"dnshomede",
		"dnsimple",
		"dnsla",
		"dnsmadeeasy",
		"dnsservices",
		"dnsupdate",
		"dode",
		"domeneshop",
		"dreamhost",
		"duckdns",
		"dyn",
		"dynadot",
		"dyndnsfree",
		"dynu",
		"easydns",
		"edgecenter",
		"edgedns",
		"edgeone",
		"efficientip",
		"epik",
		"eurodns",
		"euserv",
		"excedo",
		"exec",
		"exoscale",
		"f5xc",
		"fornex",
		"freemyip",
		"gandi",
		"gandiv5",
		"gcloud",
		"gcore",
		"gehirn",
		"gigahostno",
		"glesys",
		"gname",
		"godaddy",
		"gravity",
		"hetzner",
		"hostingde",
		"hostinger",
		"hostingnl",
		"hosttech",
		"hostup",
		"httpnet",
		"httpreq",
		"huaweicloud",
		"hurricane",
		"hyperone",
		"ibmcloud",
		"iijdpf",
		"infoblox",
		"infomaniak",
		"internetbs",
		"inwx",
		"ionos",
		"ionoscloud",
		"ipv64",
		"ispconfig",
		"ispconfigddns",
		"jdcloud",
		"joker",
		"katapult",
		"keyhelp",
		"leaseweb",
		"liara",
		"lightsail",
		"limacity",
		"linode",
		"liquidweb",
		"loopia",
		"luadns",
		"mailinabox",
		"manageengine",
		"manual",
		"metaname",
		"metaregistrar",
		"mijnhost",
		"mittwald",
		"myaddr",
		"mydnsjp",
		"mythicbeasts",
		"namecheap",
		"namedotcom",
		"namesilo",
		"namesurfer",
		"nearlyfreespeech",
		"nederhost",
		"neodigit",
		"netcup",
		"netlify",
		"netnod",
		"ngenix",
		"nicmanager",
		"nicru",
		"nifcloud",
		"njalla",
		"nodion",
		"ns1",
		"octenium",
		"omglol",
		"onecloudru",
		"onlinenet",
		"oraclecloud",
		"otc",
		"ovh",
		"pdns",
		"plesk",
		"pointdns",
		"porkbun",
		"rackspace",
		"rage4",
		"rainyun",
		"rcodezero",
		"regfish",
		"regru",
		"rimuhosting",
		"route53",
		"safedns",
		"sakuracloud",
		"scaleway",
		"scannet",
		"selectel",
		"selectelv2",
		"selfhostde",
		"servercow",
		"shellrent",
		"simply",
		"sonic",
		"spaceship",
		"stackpath",
		"syse",
		"technitium",
		"tele3",
		"tencentcloud",
		"timewebcloud",
		"todaynic",
		"transip",
		"ucloud",
		"ultradns",
		"uniteddomains",
		"variomedia",
		"veesp",
		"vegadns",
		"vercel",
		"versio",
		"vinyldns",
		"virtualname",
		"vkcloud",
		"volcengine",
		"vscale",
		"vultr",
		"wannafind",
		"webnamesca",
		"webnamesru",
		"websupport",
		"wedos",
		"westcn",
		"xinnet",
		"yandex",
		"yandex360",
		"yandexcloud",
		"zilore",
		"zoneedit",
		"zoneee",
		"zonomi",
	}
	sort.Strings(providers)
	return strings.Join(providers, ", ")
}

func displayDNSHelp(w io.Writer, name string) error {
	w = tabwriter.NewWriter(w, 0, 0, 2, ' ', 0)
	ew := &errWriter{w: w}

	switch name {
	case "abion":
		// generated from: providers/dns/abion/abion.toml
		ew.writeln(`Configuration for Abion.`)
		ew.writeln(`Code:	'abion'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ABION_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ABION_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "ABION_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ABION_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "ABION_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/abion`)

	case "acmedns":
		// generated from: providers/dns/acmedns/acmedns.toml
		ew.writeln(`Configuration for Joohoi's ACME-DNS.`)
		ew.writeln(`Code:	'acmedns'`)
		ew.writeln(`Since:	'v1.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ACME_DNS_API_BASE":	The ACME-DNS API address`)
		ew.writeln(`	- "ACME_DNS_STORAGE_BASE_URL":	The ACME-DNS JSON account data server.`)
		ew.writeln(`	- "ACME_DNS_STORAGE_PATH":	The ACME-DNS JSON account data file. A per-domain account will be registered/persisted to this file and used for TXT updates.`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ACME_DNS_ALLOWLIST":	Source networks using CIDR notation (multiple values should be separated with a comma).`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/acmedns`)

	case "active24":
		// generated from: providers/dns/active24/active24.toml
		ew.writeln(`Configuration for Active24.`)
		ew.writeln(`Code:	'active24'`)
		ew.writeln(`Since:	'v4.23.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ACTIVE24_API_KEY":	API key`)
		ew.writeln(`	- "ACTIVE24_SECRET":	Secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ACTIVE24_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ACTIVE24_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ACTIVE24_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "ACTIVE24_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/active24`)

	case "alidns":
		// generated from: providers/dns/alidns/alidns.toml
		ew.writeln(`Configuration for Alibaba Cloud DNS.`)
		ew.writeln(`Code:	'alidns'`)
		ew.writeln(`Since:	'v1.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ALICLOUD_ACCESS_KEY":	Access key ID`)
		ew.writeln(`	- "ALICLOUD_RAM_ROLE":	Your instance RAM role (https://www.alibabacloud.com/help/en/ecs/user-guide/attach-an-instance-ram-role-to-an-ecs-instance)`)
		ew.writeln(`	- "ALICLOUD_SECRET_KEY":	Access Key secret`)
		ew.writeln(`	- "ALICLOUD_SECURITY_TOKEN":	STS Security Token (optional)`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ALICLOUD_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "ALICLOUD_LINE":	Line (Default: default)`)
		ew.writeln(`	- "ALICLOUD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ALICLOUD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "ALICLOUD_REGION_ID":	Region ID (Default: cn-hangzhou)`)
		ew.writeln(`	- "ALICLOUD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/alidns`)

	case "aliesa":
		// generated from: providers/dns/aliesa/aliesa.toml
		ew.writeln(`Configuration for AlibabaCloud ESA.`)
		ew.writeln(`Code:	'aliesa'`)
		ew.writeln(`Since:	'v4.29.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ALIESA_ACCESS_KEY":	Access key ID`)
		ew.writeln(`	- "ALIESA_RAM_ROLE":	Your instance RAM role (https://www.alibabacloud.com/help/en/ecs/user-guide/attach-an-instance-ram-role-to-an-ecs-instance)`)
		ew.writeln(`	- "ALIESA_SECRET_KEY":	Access Key secret`)
		ew.writeln(`	- "ALIESA_SECURITY_TOKEN":	STS Security Token (optional)`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ALIESA_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ALIESA_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ALIESA_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "ALIESA_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/aliesa`)

	case "allinkl":
		// generated from: providers/dns/allinkl/allinkl.toml
		ew.writeln(`Configuration for all-inkl.`)
		ew.writeln(`Code:	'allinkl'`)
		ew.writeln(`Since:	'v4.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ALL_INKL_LOGIN":	KAS login`)
		ew.writeln(`	- "ALL_INKL_PASSWORD":	KAS password`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ALL_INKL_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ALL_INKL_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ALL_INKL_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/allinkl`)

	case "alwaysdata":
		// generated from: providers/dns/alwaysdata/alwaysdata.toml
		ew.writeln(`Configuration for Alwaysdata.`)
		ew.writeln(`Code:	'alwaysdata'`)
		ew.writeln(`Since:	'v4.31.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ALWAYSDATA_API_KEY":	API Key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ALWAYSDATA_ACCOUNT":	Account name`)
		ew.writeln(`	- "ALWAYSDATA_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ALWAYSDATA_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ALWAYSDATA_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "ALWAYSDATA_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/alwaysdata`)

	case "anexia":
		// generated from: providers/dns/anexia/anexia.toml
		ew.writeln(`Configuration for Anexia CloudDNS.`)
		ew.writeln(`Code:	'anexia'`)
		ew.writeln(`Since:	'v4.28.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ANEXIA_TOKEN":	API token for Anexia Engine`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ANEXIA_API_URL":	API endpoint URL (default: https://engine.anexia-it.com)`)
		ew.writeln(`	- "ANEXIA_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ANEXIA_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ANEXIA_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 300)`)
		ew.writeln(`	- "ANEXIA_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/anexia`)

	case "artfiles":
		// generated from: providers/dns/artfiles/artfiles.toml
		ew.writeln(`Configuration for ArtFiles.`)
		ew.writeln(`Code:	'artfiles'`)
		ew.writeln(`Since:	'v4.32.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ARTFILES_PASSWORD":	API password`)
		ew.writeln(`	- "ARTFILES_USERNAME":	API username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ARTFILES_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ARTFILES_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ARTFILES_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 360)`)
		ew.writeln(`	- "ARTFILES_SERVER_NAME":	Your server name (Default: dcp)`)
		ew.writeln(`	- "ARTFILES_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/artfiles`)

	case "arvancloud":
		// generated from: providers/dns/arvancloud/arvancloud.toml
		ew.writeln(`Configuration for ArvanCloud.`)
		ew.writeln(`Code:	'arvancloud'`)
		ew.writeln(`Since:	'v3.8.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ARVANCLOUD_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ARVANCLOUD_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ARVANCLOUD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ARVANCLOUD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "ARVANCLOUD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/arvancloud`)

	case "auroradns":
		// generated from: providers/dns/auroradns/auroradns.toml
		ew.writeln(`Configuration for Aurora DNS.`)
		ew.writeln(`Code:	'auroradns'`)
		ew.writeln(`Since:	'v0.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "AURORA_API_KEY":	API key or username to used`)
		ew.writeln(`	- "AURORA_SECRET":	Secret password to be used`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "AURORA_ENDPOINT":	API endpoint URL`)
		ew.writeln(`	- "AURORA_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "AURORA_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "AURORA_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/auroradns`)

	case "autodns":
		// generated from: providers/dns/autodns/autodns.toml
		ew.writeln(`Configuration for Autodns.`)
		ew.writeln(`Code:	'autodns'`)
		ew.writeln(`Since:	'v3.2.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "AUTODNS_API_PASSWORD":	User Password`)
		ew.writeln(`	- "AUTODNS_API_USER":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "AUTODNS_CONTEXT":	API context (4 for production, 1 for testing. Defaults to 4)`)
		ew.writeln(`	- "AUTODNS_ENDPOINT":	API endpoint URL, defaults to https://api.autodns.com/v1/`)
		ew.writeln(`	- "AUTODNS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "AUTODNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "AUTODNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "AUTODNS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/autodns`)

	case "axelname":
		// generated from: providers/dns/axelname/axelname.toml
		ew.writeln(`Configuration for Axelname.`)
		ew.writeln(`Code:	'axelname'`)
		ew.writeln(`Since:	'v4.23.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "AXELNAME_NICKNAME":	Account nickname`)
		ew.writeln(`	- "AXELNAME_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "AXELNAME_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "AXELNAME_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "AXELNAME_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "AXELNAME_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/axelname`)

	case "azion":
		// generated from: providers/dns/azion/azion.toml
		ew.writeln(`Configuration for Azion.`)
		ew.writeln(`Code:	'azion'`)
		ew.writeln(`Since:	'v4.24.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "AZION_PERSONAL_TOKEN":	Your Azion personal token.`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "AZION_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "AZION_PAGE_SIZE":	The page size for the API request (Default: 50)`)
		ew.writeln(`	- "AZION_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "AZION_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "AZION_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/azion`)

	case "azuredns":
		// generated from: providers/dns/azuredns/azuredns.toml
		ew.writeln(`Configuration for Azure DNS.`)
		ew.writeln(`Code:	'azuredns'`)
		ew.writeln(`Since:	'v4.13.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "AZURE_CLIENT_CERTIFICATE_PATH":	Client certificate path`)
		ew.writeln(`	- "AZURE_CLIENT_ID":	Client ID`)
		ew.writeln(`	- "AZURE_CLIENT_SECRET":	Client secret`)
		ew.writeln(`	- "AZURE_TENANT_ID":	Tenant ID`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "AZURE_AUTH_METHOD":	Specify which authentication method to use`)
		ew.writeln(`	- "AZURE_AUTH_MSI_TIMEOUT":	Managed Identity timeout duration`)
		ew.writeln(`	- "AZURE_ENVIRONMENT":	Azure environment, one of: public, usgovernment, and china`)
		ew.writeln(`	- "AZURE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "AZURE_PRIVATE_ZONE":	Set to true to use Azure Private DNS Zones and not public`)
		ew.writeln(`	- "AZURE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "AZURE_RESOURCE_GROUP":	DNS zone resource group`)
		ew.writeln(`	- "AZURE_SERVICEDISCOVERY_FILTER":	Advanced ServiceDiscovery filter using Kusto query condition`)
		ew.writeln(`	- "AZURE_SUBSCRIPTION_ID":	DNS zone subscription ID`)
		ew.writeln(`	- "AZURE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)
		ew.writeln(`	- "AZURE_ZONE_NAME":	Zone name to use inside Azure DNS service to add the TXT record in`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/azuredns`)

	case "baiducloud":
		// generated from: providers/dns/baiducloud/baiducloud.toml
		ew.writeln(`Configuration for Baidu Cloud.`)
		ew.writeln(`Code:	'baiducloud'`)
		ew.writeln(`Since:	'v4.23.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "BAIDUCLOUD_ACCESS_KEY_ID":	Access key`)
		ew.writeln(`	- "BAIDUCLOUD_SECRET_ACCESS_KEY":	Secret access key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "BAIDUCLOUD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "BAIDUCLOUD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "BAIDUCLOUD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/baiducloud`)

	case "beget":
		// generated from: providers/dns/beget/beget.toml
		ew.writeln(`Configuration for Beget.com.`)
		ew.writeln(`Code:	'beget'`)
		ew.writeln(`Since:	'v4.27.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "BEGET_PASSWORD":	API password`)
		ew.writeln(`	- "BEGET_USERNAME":	API username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "BEGET_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "BEGET_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 30)`)
		ew.writeln(`	- "BEGET_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 300)`)
		ew.writeln(`	- "BEGET_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/beget`)

	case "binarylane":
		// generated from: providers/dns/binarylane/binarylane.toml
		ew.writeln(`Configuration for Binary Lane.`)
		ew.writeln(`Code:	'binarylane'`)
		ew.writeln(`Since:	'v4.26.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "BINARYLANE_API_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "BINARYLANE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "BINARYLANE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "BINARYLANE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "BINARYLANE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/binarylane`)

	case "bindman":
		// generated from: providers/dns/bindman/bindman.toml
		ew.writeln(`Configuration for Bindman.`)
		ew.writeln(`Code:	'bindman'`)
		ew.writeln(`Since:	'v2.6.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "BINDMAN_MANAGER_ADDRESS":	The server URL, should have scheme, hostname, and port (if required) of the Bindman-DNS Manager server`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "BINDMAN_HTTP_TIMEOUT":	API request timeout in seconds (Default: 60)`)
		ew.writeln(`	- "BINDMAN_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "BINDMAN_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/bindman`)

	case "bluecat":
		// generated from: providers/dns/bluecat/bluecat.toml
		ew.writeln(`Configuration for Bluecat.`)
		ew.writeln(`Code:	'bluecat'`)
		ew.writeln(`Since:	'v0.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "BLUECAT_CONFIG_NAME":	Configuration name`)
		ew.writeln(`	- "BLUECAT_DNS_VIEW":	External DNS View Name`)
		ew.writeln(`	- "BLUECAT_PASSWORD":	API password`)
		ew.writeln(`	- "BLUECAT_SERVER_URL":	The server URL, should have scheme, hostname, and port (if required) of the authoritative Bluecat BAM serve`)
		ew.writeln(`	- "BLUECAT_USER_NAME":	API username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "BLUECAT_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "BLUECAT_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "BLUECAT_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "BLUECAT_SKIP_DEPLOY":	Skip deployments`)
		ew.writeln(`	- "BLUECAT_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/bluecat`)

	case "bluecatv2":
		// generated from: providers/dns/bluecatv2/bluecatv2.toml
		ew.writeln(`Configuration for Bluecat v2.`)
		ew.writeln(`Code:	'bluecatv2'`)
		ew.writeln(`Since:	'v4.32.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "BLUECATV2_CONFIG_NAME":	Configuration name`)
		ew.writeln(`	- "BLUECATV2_PASSWORD":	API password`)
		ew.writeln(`	- "BLUECATV2_SERVER_URL":	The server URL: it should have a scheme, hostname, and port (if required) of the authoritative Bluecat BAM serve`)
		ew.writeln(`	- "BLUECATV2_USERNAME":	API username`)
		ew.writeln(`	- "BLUECATV2_VIEW_NAME":	DNS View Name`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "BLUECATV2_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "BLUECATV2_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "BLUECATV2_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "BLUECATV2_SKIP_DEPLOY":	Skip quick deployments`)
		ew.writeln(`	- "BLUECATV2_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/bluecatv2`)

	case "bookmyname":
		// generated from: providers/dns/bookmyname/bookmyname.toml
		ew.writeln(`Configuration for BookMyName.`)
		ew.writeln(`Code:	'bookmyname'`)
		ew.writeln(`Since:	'v4.23.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "BOOKMYNAME_PASSWORD":	Password`)
		ew.writeln(`	- "BOOKMYNAME_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "BOOKMYNAME_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "BOOKMYNAME_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "BOOKMYNAME_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "BOOKMYNAME_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/bookmyname`)

	case "bunny":
		// generated from: providers/dns/bunny/bunny.toml
		ew.writeln(`Configuration for Bunny.`)
		ew.writeln(`Code:	'bunny'`)
		ew.writeln(`Since:	'v4.11.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "BUNNY_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "BUNNY_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "BUNNY_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "BUNNY_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "BUNNY_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/bunny`)

	case "checkdomain":
		// generated from: providers/dns/checkdomain/checkdomain.toml
		ew.writeln(`Configuration for Checkdomain.`)
		ew.writeln(`Code:	'checkdomain'`)
		ew.writeln(`Since:	'v3.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CHECKDOMAIN_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CHECKDOMAIN_ENDPOINT":	API endpoint URL, defaults to https://api.checkdomain.de`)
		ew.writeln(`	- "CHECKDOMAIN_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "CHECKDOMAIN_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 300)`)
		ew.writeln(`	- "CHECKDOMAIN_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 7)`)
		ew.writeln(`	- "CHECKDOMAIN_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/checkdomain`)

	case "civo":
		// generated from: providers/dns/civo/civo.toml
		ew.writeln(`Configuration for Civo.`)
		ew.writeln(`Code:	'civo'`)
		ew.writeln(`Since:	'v4.9.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CIVO_TOKEN":	Authentication token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CIVO_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 30)`)
		ew.writeln(`	- "CIVO_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 300)`)
		ew.writeln(`	- "CIVO_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/civo`)

	case "clouddns":
		// generated from: providers/dns/clouddns/clouddns.toml
		ew.writeln(`Configuration for CloudDNS.`)
		ew.writeln(`Code:	'clouddns'`)
		ew.writeln(`Since:	'v3.6.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CLOUDDNS_CLIENT_ID":	Client ID`)
		ew.writeln(`	- "CLOUDDNS_EMAIL":	Account email`)
		ew.writeln(`	- "CLOUDDNS_PASSWORD":	Account password`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CLOUDDNS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "CLOUDDNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 5)`)
		ew.writeln(`	- "CLOUDDNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "CLOUDDNS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/clouddns`)

	case "cloudflare":
		// generated from: providers/dns/cloudflare/cloudflare.toml
		ew.writeln(`Configuration for Cloudflare.`)
		ew.writeln(`Code:	'cloudflare'`)
		ew.writeln(`Since:	'v0.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CF_API_EMAIL":	Account email`)
		ew.writeln(`	- "CF_API_KEY":	API key`)
		ew.writeln(`	- "CF_DNS_API_TOKEN":	API token with DNS:Edit permission (since v3.1.0)`)
		ew.writeln(`	- "CF_ZONE_API_TOKEN":	API token with Zone:Read permission (since v3.1.0)`)
		ew.writeln(`	- "CLOUDFLARE_API_KEY":	Alias to CF_API_KEY`)
		ew.writeln(`	- "CLOUDFLARE_DNS_API_TOKEN":	Alias to CF_DNS_API_TOKEN`)
		ew.writeln(`	- "CLOUDFLARE_EMAIL":	Alias to CF_API_EMAIL`)
		ew.writeln(`	- "CLOUDFLARE_ZONE_API_TOKEN":	Alias to CF_ZONE_API_TOKEN`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CLOUDFLARE_BASE_URL":	API base URL (Default: https://api.cloudflare.com/client/v4)`)
		ew.writeln(`	- "CLOUDFLARE_HTTP_TIMEOUT":	API request timeout in seconds (Default: )`)
		ew.writeln(`	- "CLOUDFLARE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "CLOUDFLARE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "CLOUDFLARE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/cloudflare`)

	case "cloudns":
		// generated from: providers/dns/cloudns/cloudns.toml
		ew.writeln(`Configuration for ClouDNS.`)
		ew.writeln(`Code:	'cloudns'`)
		ew.writeln(`Since:	'v2.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CLOUDNS_AUTH_ID":	The API user ID`)
		ew.writeln(`	- "CLOUDNS_AUTH_PASSWORD":	The password for API user ID`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CLOUDNS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "CLOUDNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "CLOUDNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 180)`)
		ew.writeln(`	- "CLOUDNS_SUB_AUTH_ID":	The API sub user ID`)
		ew.writeln(`	- "CLOUDNS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/cloudns`)

	case "cloudru":
		// generated from: providers/dns/cloudru/cloudru.toml
		ew.writeln(`Configuration for Cloud.ru.`)
		ew.writeln(`Code:	'cloudru'`)
		ew.writeln(`Since:	'v4.14.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CLOUDRU_KEY_ID":	Key ID (login)`)
		ew.writeln(`	- "CLOUDRU_SECRET":	Key Secret`)
		ew.writeln(`	- "CLOUDRU_SERVICE_INSTANCE_ID":	Service Instance ID (parentId)`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CLOUDRU_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "CLOUDRU_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 5)`)
		ew.writeln(`	- "CLOUDRU_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 300)`)
		ew.writeln(`	- "CLOUDRU_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 120)`)
		ew.writeln(`	- "CLOUDRU_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/cloudru`)

	case "com35":
		// generated from: providers/dns/com35/com35.toml
		ew.writeln(`Configuration for 35.com/三五互联.`)
		ew.writeln(`Code:	'com35'`)
		ew.writeln(`Since:	'v4.31.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "COM35_PASSWORD":	API password`)
		ew.writeln(`	- "COM35_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "COM35_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "COM35_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "COM35_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "COM35_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/com35`)

	case "connbyte":
		// generated from: providers/dns/connbyte/connbyte.toml
		ew.writeln(`Configuration for Connbyte.`)
		ew.writeln(`Code:	'connbyte'`)
		ew.writeln(`Since:	'v5.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CONNBYTE_TOKEN":	Token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CONNBYTE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "CONNBYTE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "CONNBYTE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "CONNBYTE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/connbyte`)

	case "conoha":
		// generated from: providers/dns/conoha/conoha.toml
		ew.writeln(`Configuration for ConoHa v2.`)
		ew.writeln(`Code:	'conoha'`)
		ew.writeln(`Since:	'v1.2.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CONOHA_API_PASSWORD":	The API password`)
		ew.writeln(`	- "CONOHA_API_USERNAME":	The API username`)
		ew.writeln(`	- "CONOHA_TENANT_ID":	Tenant ID`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CONOHA_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "CONOHA_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "CONOHA_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "CONOHA_REGION":	The region (Default: tyo1)`)
		ew.writeln(`	- "CONOHA_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/conoha`)

	case "conohav3":
		// generated from: providers/dns/conohav3/conohav3.toml
		ew.writeln(`Configuration for ConoHa v3.`)
		ew.writeln(`Code:	'conohav3'`)
		ew.writeln(`Since:	'v4.24.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CONOHAV3_API_PASSWORD":	The API password`)
		ew.writeln(`	- "CONOHAV3_API_USER_ID":	The API user ID`)
		ew.writeln(`	- "CONOHAV3_TENANT_ID":	Tenant ID`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CONOHAV3_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "CONOHAV3_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "CONOHAV3_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "CONOHAV3_REGION":	The region (Default: c3j1)`)
		ew.writeln(`	- "CONOHAV3_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/conohav3`)

	case "constellix":
		// generated from: providers/dns/constellix/constellix.toml
		ew.writeln(`Configuration for Constellix.`)
		ew.writeln(`Code:	'constellix'`)
		ew.writeln(`Since:	'v3.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CONSTELLIX_API_KEY":	User API key`)
		ew.writeln(`	- "CONSTELLIX_SECRET_KEY":	User secret key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CONSTELLIX_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "CONSTELLIX_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "CONSTELLIX_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "CONSTELLIX_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/constellix`)

	case "corenetworks":
		// generated from: providers/dns/corenetworks/corenetworks.toml
		ew.writeln(`Configuration for Core-Networks.`)
		ew.writeln(`Code:	'corenetworks'`)
		ew.writeln(`Since:	'v4.20.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CORENETWORKS_LOGIN":	The username of the API account`)
		ew.writeln(`	- "CORENETWORKS_PASSWORD":	The password`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CORENETWORKS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "CORENETWORKS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "CORENETWORKS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "CORENETWORKS_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)
		ew.writeln(`	- "CORENETWORKS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 3600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/corenetworks`)

	case "cpanel":
		// generated from: providers/dns/cpanel/cpanel.toml
		ew.writeln(`Configuration for CPanel/WHM.`)
		ew.writeln(`Code:	'cpanel'`)
		ew.writeln(`Since:	'v4.16.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CPANEL_BASE_URL":	API server URL`)
		ew.writeln(`	- "CPANEL_TOKEN":	API token`)
		ew.writeln(`	- "CPANEL_USERNAME":	username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CPANEL_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "CPANEL_MODE":	use cpanel API or WHM API (Default: cpanel)`)
		ew.writeln(`	- "CPANEL_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "CPANEL_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "CPANEL_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/cpanel`)

	case "curanet":
		// generated from: providers/dns/curanet/curanet.toml
		ew.writeln(`Configuration for Curanet.`)
		ew.writeln(`Code:	'curanet'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CURANET_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CURANET_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "CURANET_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "CURANET_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "CURANET_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/curanet`)

	case "czechia":
		// generated from: providers/dns/czechia/czechia.toml
		ew.writeln(`Configuration for Czechia.`)
		ew.writeln(`Code:	'czechia'`)
		ew.writeln(`Since:	'v4.33.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "CZECHIA_TOKEN":	Authorization token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "CZECHIA_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "CZECHIA_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "CZECHIA_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "CZECHIA_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/czechia`)

	case "dandomain":
		// generated from: providers/dns/dandomain/dandomain.toml
		ew.writeln(`Configuration for DanDomain.`)
		ew.writeln(`Code:	'dandomain'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DANDOMAIN_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DANDOMAIN_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DANDOMAIN_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DANDOMAIN_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DANDOMAIN_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dandomain`)

	case "ddnss":
		// generated from: providers/dns/ddnss/ddnss.toml
		ew.writeln(`Configuration for DDnss (DynDNS Service).`)
		ew.writeln(`Code:	'ddnss'`)
		ew.writeln(`Since:	'v4.32.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DDNSS_KEY":	Update key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DDNSS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DDNSS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DDNSS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DDNSS_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)
		ew.writeln(`	- "DDNSS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/ddnss`)

	case "derak":
		// generated from: providers/dns/derak/derak.toml
		ew.writeln(`Configuration for Derak Cloud.`)
		ew.writeln(`Code:	'derak'`)
		ew.writeln(`Since:	'v4.12.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DERAK_API_KEY":	The API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DERAK_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DERAK_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 5)`)
		ew.writeln(`	- "DERAK_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "DERAK_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)
		ew.writeln(`	- "DERAK_WEBSITE_ID":	Force the zone/website ID`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/derak`)

	case "desec":
		// generated from: providers/dns/desec/desec.toml
		ew.writeln(`Configuration for deSEC.io.`)
		ew.writeln(`Code:	'desec'`)
		ew.writeln(`Since:	'v3.7.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DESEC_TOKEN":	Domain token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DESEC_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DESEC_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 4)`)
		ew.writeln(`	- "DESEC_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "DESEC_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 3600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/desec`)

	case "designate":
		// generated from: providers/dns/designate/designate.toml
		ew.writeln(`Configuration for Designate DNSaaS for Openstack.`)
		ew.writeln(`Code:	'designate'`)
		ew.writeln(`Since:	'v2.2.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "OS_APPLICATION_CREDENTIAL_ID":	Application credential ID`)
		ew.writeln(`	- "OS_APPLICATION_CREDENTIAL_NAME":	Application credential name`)
		ew.writeln(`	- "OS_APPLICATION_CREDENTIAL_SECRET":	Application credential secret`)
		ew.writeln(`	- "OS_AUTH_URL":	Identity endpoint URL`)
		ew.writeln(`	- "OS_PASSWORD":	Password`)
		ew.writeln(`	- "OS_PROJECT_NAME":	Project name`)
		ew.writeln(`	- "OS_REGION_NAME":	Region name`)
		ew.writeln(`	- "OS_USERNAME":	Username`)
		ew.writeln(`	- "OS_USER_ID":	User ID`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DESIGNATE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "DESIGNATE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 600)`)
		ew.writeln(`	- "DESIGNATE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 10)`)
		ew.writeln(`	- "DESIGNATE_ZONE_NAME":	The zone name to use in the OpenStack Project to manage TXT records.`)
		ew.writeln(`	- "OS_PROJECT_ID":	Project ID`)
		ew.writeln(`	- "OS_TENANT_NAME":	Tenant name (deprecated see OS_PROJECT_NAME and OS_PROJECT_ID)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/designate`)

	case "digitalocean":
		// generated from: providers/dns/digitalocean/digitalocean.toml
		ew.writeln(`Configuration for Digital Ocean.`)
		ew.writeln(`Code:	'digitalocean'`)
		ew.writeln(`Since:	'v0.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DO_AUTH_TOKEN":	Authentication token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DO_API_URL":	The URL of the API`)
		ew.writeln(`	- "DO_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DO_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 5)`)
		ew.writeln(`	- "DO_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DO_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 30)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/digitalocean`)

	case "dinahosting":
		// generated from: providers/dns/dinahosting/dinahosting.toml
		ew.writeln(`Configuration for Dinahosting.`)
		ew.writeln(`Code:	'dinahosting'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DINAHOSTING_PASSWORD":	Password`)
		ew.writeln(`	- "DINAHOSTING_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DINAHOSTING_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DINAHOSTING_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DINAHOSTING_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DINAHOSTING_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dinahosting`)

	case "directadmin":
		// generated from: providers/dns/directadmin/directadmin.toml
		ew.writeln(`Configuration for DirectAdmin.`)
		ew.writeln(`Code:	'directadmin'`)
		ew.writeln(`Since:	'v4.18.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DIRECTADMIN_API_URL":	URL of the API`)
		ew.writeln(`	- "DIRECTADMIN_PASSWORD":	API password`)
		ew.writeln(`	- "DIRECTADMIN_USERNAME":	API username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DIRECTADMIN_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DIRECTADMIN_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 5)`)
		ew.writeln(`	- "DIRECTADMIN_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DIRECTADMIN_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 30)`)
		ew.writeln(`	- "DIRECTADMIN_ZONE_NAME":	Zone name used to add the TXT record`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/directadmin`)

	case "dns51":
		// generated from: providers/dns/dns51/dns51.toml
		ew.writeln(`Configuration for 51DNS.`)
		ew.writeln(`Code:	'dns51'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DNS51_API_KEY":	API key`)
		ew.writeln(`	- "DNS51_API_SECRET":	API secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DNS51_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DNS51_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DNS51_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DNS51_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dns51`)

	case "dnscale":
		// generated from: providers/dns/dnscale/dnscale.toml
		ew.writeln(`Configuration for DNScale.`)
		ew.writeln(`Code:	'dnscale'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DNSCALE_API_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DNSCALE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DNSCALE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DNSCALE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DNSCALE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dnscale`)

	case "dnsexit":
		// generated from: providers/dns/dnsexit/dnsexit.toml
		ew.writeln(`Configuration for DNSExit.`)
		ew.writeln(`Code:	'dnsexit'`)
		ew.writeln(`Since:	'v4.32.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DNSEXIT_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DNSEXIT_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DNSEXIT_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "DNSEXIT_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 300)`)
		ew.writeln(`	- "DNSEXIT_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dnsexit`)

	case "dnshomede":
		// generated from: providers/dns/dnshomede/dnshomede.toml
		ew.writeln(`Configuration for dnsHome.de.`)
		ew.writeln(`Code:	'dnshomede'`)
		ew.writeln(`Since:	'v4.10.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DNSHOMEDE_CREDENTIALS":	Comma-separated list of domain:password credential pairs`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DNSHOMEDE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DNSHOMEDE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 1200)`)
		ew.writeln(`	- "DNSHOMEDE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 2)`)
		ew.writeln(`	- "DNSHOMEDE_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dnshomede`)

	case "dnsimple":
		// generated from: providers/dns/dnsimple/dnsimple.toml
		ew.writeln(`Configuration for DNSimple.`)
		ew.writeln(`Code:	'dnsimple'`)
		ew.writeln(`Since:	'v0.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DNSIMPLE_OAUTH_TOKEN":	OAuth token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DNSIMPLE_BASE_URL":	API endpoint URL`)
		ew.writeln(`	- "DNSIMPLE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DNSIMPLE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DNSIMPLE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dnsimple`)

	case "dnsla":
		// generated from: providers/dns/dnsla/dnsla.toml
		ew.writeln(`Configuration for dns.la.`)
		ew.writeln(`Code:	'dnsla'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DNSLA_API_ID":	API ID`)
		ew.writeln(`	- "DNSLA_API_SECRET":	API secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DNSLA_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DNSLA_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DNSLA_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DNSLA_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dnsla`)

	case "dnsmadeeasy":
		// generated from: providers/dns/dnsmadeeasy/dnsmadeeasy.toml
		ew.writeln(`Configuration for DNS Made Easy.`)
		ew.writeln(`Code:	'dnsmadeeasy'`)
		ew.writeln(`Since:	'v0.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DNSMADEEASY_API_KEY":	The API key`)
		ew.writeln(`	- "DNSMADEEASY_API_SECRET":	The API Secret key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DNSMADEEASY_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "DNSMADEEASY_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DNSMADEEASY_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DNSMADEEASY_SANDBOX":	Activate the sandbox (boolean)`)
		ew.writeln(`	- "DNSMADEEASY_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dnsmadeeasy`)

	case "dnsservices":
		// generated from: providers/dns/dnsservices/dnsservices.toml
		ew.writeln(`Configuration for DNS.services.`)
		ew.writeln(`Code:	'dnsservices'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DNSSERVICES_PASSWORD":	Password`)
		ew.writeln(`	- "DNSSERVICES_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DNSSERVICES_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DNSSERVICES_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DNSSERVICES_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DNSSERVICES_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dnsservices`)

	case "dnsupdate":
		// generated from: providers/dns/dnsupdate/dnsupdate.toml
		ew.writeln(`Configuration for DNS Update (RFC2136).`)
		ew.writeln(`Code:	'dnsupdate'`)
		ew.writeln(`Since:	'v0.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DNSUPDATE_NAMESERVER":	Network address in the form "host" or "host:port"`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DNSUPDATE_DNS_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "DNSUPDATE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DNSUPDATE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DNSUPDATE_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)
		ew.writeln(`	- "DNSUPDATE_TSIG_ALGORITHM":	TSIG algorithm. See [miekg/dns#tsig.go](https://github.com/miekg/dns/blob/master/tsig.go) for supported values. To disable TSIG authentication, leave the 'DNSUPDATE_TSIG_KEY' or 'DNSUPDATE_TSIG_SECRET' variables unset.`)
		ew.writeln(`	- "DNSUPDATE_TSIG_FILE":	Path to a key file generated by tsig-keygen`)
		ew.writeln(`	- "DNSUPDATE_TSIG_GSS_KEYTAB_FILE":	Path to Kerberos keytab file. The TSIG algorithm must be 'gss-tsig.'.`)
		ew.writeln(`	- "DNSUPDATE_TSIG_GSS_PASSWORD":	Kerberos password. The TSIG algorithm must be 'gss-tsig.'.`)
		ew.writeln(`	- "DNSUPDATE_TSIG_GSS_REALM":	Kerberos realm. The TSIG algorithm must be 'gss-tsig.'.`)
		ew.writeln(`	- "DNSUPDATE_TSIG_GSS_USERNAME":	Kerberos username. The TSIG algorithm must be 'gss-tsig.'.`)
		ew.writeln(`	- "DNSUPDATE_TSIG_KEY":	Name of the secret key as defined in DNS server configuration. To disable TSIG authentication, leave the 'DNSUPDATE_TSIG_KEY' variable unset.`)
		ew.writeln(`	- "DNSUPDATE_TSIG_SECRET":	Secret key payload. To disable TSIG authentication, leave the 'DNSUPDATE_TSIG_SECRET' variable unset.`)
		ew.writeln(`	- "DNSUPDATE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)
		ew.writeln(`	- "DNSUPDATE_ZONES":	List of potential zones (separated by commas)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dnsupdate`)

	case "dode":
		// generated from: providers/dns/dode/dode.toml
		ew.writeln(`Configuration for Domain Offensive (do.de).`)
		ew.writeln(`Code:	'dode'`)
		ew.writeln(`Since:	'v2.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DODE_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DODE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DODE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DODE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DODE_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dode`)

	case "domeneshop":
		// generated from: providers/dns/domeneshop/domeneshop.toml
		ew.writeln(`Configuration for Domeneshop.`)
		ew.writeln(`Code:	'domeneshop'`)
		ew.writeln(`Since:	'v4.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DOMENESHOP_API_SECRET":	API secret`)
		ew.writeln(`	- "DOMENESHOP_API_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DOMENESHOP_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DOMENESHOP_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 20)`)
		ew.writeln(`	- "DOMENESHOP_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/domeneshop`)

	case "dreamhost":
		// generated from: providers/dns/dreamhost/dreamhost.toml
		ew.writeln(`Configuration for DreamHost.`)
		ew.writeln(`Code:	'dreamhost'`)
		ew.writeln(`Since:	'v1.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DREAMHOST_API_KEY":	The API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DREAMHOST_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DREAMHOST_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 60)`)
		ew.writeln(`	- "DREAMHOST_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 3600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dreamhost`)

	case "duckdns":
		// generated from: providers/dns/duckdns/duckdns.toml
		ew.writeln(`Configuration for Duck DNS.`)
		ew.writeln(`Code:	'duckdns'`)
		ew.writeln(`Since:	'v0.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DUCKDNS_TOKEN":	Account token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DUCKDNS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DUCKDNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DUCKDNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DUCKDNS_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/duckdns`)

	case "dyn":
		// generated from: providers/dns/dyn/dyn.toml
		ew.writeln(`Configuration for Dyn.`)
		ew.writeln(`Code:	'dyn'`)
		ew.writeln(`Since:	'v0.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DYN_CUSTOMER_NAME":	Customer name`)
		ew.writeln(`	- "DYN_PASSWORD":	Password`)
		ew.writeln(`	- "DYN_USER_NAME":	User name`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DYN_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "DYN_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DYN_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DYN_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dyn`)

	case "dynadot":
		// generated from: providers/dns/dynadot/dynadot.toml
		ew.writeln(`Configuration for Dynadot.`)
		ew.writeln(`Code:	'dynadot'`)
		ew.writeln(`Since:	'v5.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DYNADOT_API_KEY":	API key`)
		ew.writeln(`	- "DYNADOT_API_SECRET":	API secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DYNADOT_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DYNADOT_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DYNADOT_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "DYNADOT_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dynadot`)

	case "dyndnsfree":
		// generated from: providers/dns/dyndnsfree/dyndnsfree.toml
		ew.writeln(`Configuration for DynDnsFree.de.`)
		ew.writeln(`Code:	'dyndnsfree'`)
		ew.writeln(`Since:	'v4.23.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DYNDNSFREE_PASSWORD":	Password`)
		ew.writeln(`	- "DYNDNSFREE_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DYNDNSFREE_HTTP_TIMEOUT":	Request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DYNDNSFREE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "DYNDNSFREE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dyndnsfree`)

	case "dynu":
		// generated from: providers/dns/dynu/dynu.toml
		ew.writeln(`Configuration for Dynu.`)
		ew.writeln(`Code:	'dynu'`)
		ew.writeln(`Since:	'v3.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "DYNU_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "DYNU_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "DYNU_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "DYNU_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 180)`)
		ew.writeln(`	- "DYNU_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/dynu`)

	case "easydns":
		// generated from: providers/dns/easydns/easydns.toml
		ew.writeln(`Configuration for EasyDNS.`)
		ew.writeln(`Code:	'easydns'`)
		ew.writeln(`Since:	'v2.6.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "EASYDNS_KEY":	API Key`)
		ew.writeln(`	- "EASYDNS_TOKEN":	API Token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "EASYDNS_ENDPOINT":	The endpoint URL of the API Server`)
		ew.writeln(`	- "EASYDNS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "EASYDNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "EASYDNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "EASYDNS_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)
		ew.writeln(`	- "EASYDNS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/easydns`)

	case "edgecenter":
		// generated from: providers/dns/edgecenter/edgecenter.toml
		ew.writeln(`Configuration for EdgeCenter.`)
		ew.writeln(`Code:	'edgecenter'`)
		ew.writeln(`Since:	'v4.29.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "EDGECENTER_PERMANENT_API_TOKEN":	Permanent API token (https://edgecenter.ru/blog/permanent-api-token-explained/)`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "EDGECENTER_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "EDGECENTER_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 20)`)
		ew.writeln(`	- "EDGECENTER_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 360)`)
		ew.writeln(`	- "EDGECENTER_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/edgecenter`)

	case "edgedns":
		// generated from: providers/dns/edgedns/edgedns.toml
		ew.writeln(`Configuration for Akamai EdgeDNS.`)
		ew.writeln(`Code:	'edgedns'`)
		ew.writeln(`Since:	'v3.9.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "AKAMAI_ACCESS_TOKEN":	Access token, managed by the Akamai EdgeGrid client`)
		ew.writeln(`	- "AKAMAI_CLIENT_SECRET":	Client secret, managed by the Akamai EdgeGrid client`)
		ew.writeln(`	- "AKAMAI_CLIENT_TOKEN":	Client token, managed by the Akamai EdgeGrid client`)
		ew.writeln(`	- "AKAMAI_EDGERC":	Path to the .edgerc file, managed by the Akamai EdgeGrid client`)
		ew.writeln(`	- "AKAMAI_EDGERC_SECTION":	Configuration section, managed by the Akamai EdgeGrid client`)
		ew.writeln(`	- "AKAMAI_HOST":	API host, managed by the Akamai EdgeGrid client`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "AKAMAI_ACCOUNT_SWITCH_KEY":	Target account ID when the DNS zone and credentials belong to different accounts`)
		ew.writeln(`	- "AKAMAI_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 15)`)
		ew.writeln(`	- "AKAMAI_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 180)`)
		ew.writeln(`	- "AKAMAI_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/edgedns`)

	case "edgeone":
		// generated from: providers/dns/edgeone/edgeone.toml
		ew.writeln(`Configuration for Tencent EdgeOne.`)
		ew.writeln(`Code:	'edgeone'`)
		ew.writeln(`Since:	'v4.26.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "EDGEONE_SECRET_ID":	Access key ID`)
		ew.writeln(`	- "EDGEONE_SECRET_KEY":	Access Key secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "EDGEONE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "EDGEONE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 30)`)
		ew.writeln(`	- "EDGEONE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 1200)`)
		ew.writeln(`	- "EDGEONE_REGION":	Region`)
		ew.writeln(`	- "EDGEONE_SESSION_TOKEN":	Access Key token`)
		ew.writeln(`	- "EDGEONE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)
		ew.writeln(`	- "EDGEONE_ZONES_MAPPING":	Mapping between DNS zones and site IDs. (ex: 'example.org:id1,example.com:id2')`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/edgeone`)

	case "efficientip":
		// generated from: providers/dns/efficientip/efficientip.toml
		ew.writeln(`Configuration for Efficient IP.`)
		ew.writeln(`Code:	'efficientip'`)
		ew.writeln(`Since:	'v4.13.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "EFFICIENTIP_DNS_NAME":	DNS name (ex: dns.smart)`)
		ew.writeln(`	- "EFFICIENTIP_HOSTNAME":	Hostname (ex: foo.example.com)`)
		ew.writeln(`	- "EFFICIENTIP_PASSWORD":	Password`)
		ew.writeln(`	- "EFFICIENTIP_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "EFFICIENTIP_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "EFFICIENTIP_INSECURE_SKIP_VERIFY":	Whether or not to verify EfficientIP API certificate`)
		ew.writeln(`	- "EFFICIENTIP_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "EFFICIENTIP_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "EFFICIENTIP_VIEW_NAME":	View name (ex: external)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/efficientip`)

	case "epik":
		// generated from: providers/dns/epik/epik.toml
		ew.writeln(`Configuration for Epik.`)
		ew.writeln(`Code:	'epik'`)
		ew.writeln(`Since:	'v4.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "EPIK_SIGNATURE":	Epik API signature (https://registrar.epik.com/account/api-settings/)`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "EPIK_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "EPIK_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "EPIK_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "EPIK_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 3600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/epik`)

	case "eurodns":
		// generated from: providers/dns/eurodns/eurodns.toml
		ew.writeln(`Configuration for EuroDNS.`)
		ew.writeln(`Code:	'eurodns'`)
		ew.writeln(`Since:	'v4.33.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "EURODNS_API_KEY":	API key`)
		ew.writeln(`	- "EURODNS_APP_ID":	Application ID`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "EURODNS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "EURODNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "EURODNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "EURODNS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/eurodns`)

	case "euserv":
		// generated from: providers/dns/euserv/euserv.toml
		ew.writeln(`Configuration for EUserv.`)
		ew.writeln(`Code:	'euserv'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "EUSERV_EMAIL":	The customer email address. You can also use the customer id instead.`)
		ew.writeln(`	- "EUSERV_ORDER_ID":	The order ID of the API contract that you want to use for this login session.`)
		ew.writeln(`	- "EUSERV_PASSWORD":	The customer account password.`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "EUSERV_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "EUSERV_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "EUSERV_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "EUSERV_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/euserv`)

	case "excedo":
		// generated from: providers/dns/excedo/excedo.toml
		ew.writeln(`Configuration for Excedo.`)
		ew.writeln(`Code:	'excedo'`)
		ew.writeln(`Since:	'v4.33.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "EXCEDO_API_KEY":	API key`)
		ew.writeln(`	- "EXCEDO_API_URL":	API base URL`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "EXCEDO_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "EXCEDO_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "EXCEDO_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 300)`)
		ew.writeln(`	- "EXCEDO_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/excedo`)

	case "exec":
		// generated from: providers/dns/exec/exec.toml
		ew.writeln(`Configuration for External program.`)
		ew.writeln(`Code:	'exec'`)
		ew.writeln(`Since:	'v0.5.0'`)
		ew.writeln()

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/exec`)

	case "exoscale":
		// generated from: providers/dns/exoscale/exoscale.toml
		ew.writeln(`Configuration for Exoscale.`)
		ew.writeln(`Code:	'exoscale'`)
		ew.writeln(`Since:	'v0.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "EXOSCALE_API_KEY":	API key`)
		ew.writeln(`	- "EXOSCALE_API_SECRET":	API secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "EXOSCALE_ENDPOINT":	API endpoint URL`)
		ew.writeln(`	- "EXOSCALE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 60)`)
		ew.writeln(`	- "EXOSCALE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "EXOSCALE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "EXOSCALE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/exoscale`)

	case "f5xc":
		// generated from: providers/dns/f5xc/f5xc.toml
		ew.writeln(`Configuration for F5 XC.`)
		ew.writeln(`Code:	'f5xc'`)
		ew.writeln(`Since:	'v4.23.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "F5XC_API_TOKEN":	API token`)
		ew.writeln(`	- "F5XC_GROUP_NAME":	Group name`)
		ew.writeln(`	- "F5XC_TENANT_NAME":	XC Tenant shortname`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "F5XC_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "F5XC_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "F5XC_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "F5XC_SERVER":	Server domain (Default: console.ves.volterra.io)`)
		ew.writeln(`	- "F5XC_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/f5xc`)

	case "fornex":
		// generated from: providers/dns/fornex/fornex.toml
		ew.writeln(`Configuration for Fornex.`)
		ew.writeln(`Code:	'fornex'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "FORNEX_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "FORNEX_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "FORNEX_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "FORNEX_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "FORNEX_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/fornex`)

	case "freemyip":
		// generated from: providers/dns/freemyip/freemyip.toml
		ew.writeln(`Configuration for freemyip.com.`)
		ew.writeln(`Code:	'freemyip'`)
		ew.writeln(`Since:	'v4.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "FREEMYIP_TOKEN":	Account token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "FREEMYIP_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "FREEMYIP_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "FREEMYIP_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "FREEMYIP_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)
		ew.writeln(`	- "FREEMYIP_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 3600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/freemyip`)

	case "gandi":
		// generated from: providers/dns/gandi/gandi.toml
		ew.writeln(`Configuration for Gandi.`)
		ew.writeln(`Code:	'gandi'`)
		ew.writeln(`Since:	'v0.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "GANDI_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "GANDI_HTTP_TIMEOUT":	API request timeout in seconds (Default: 60)`)
		ew.writeln(`	- "GANDI_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 60)`)
		ew.writeln(`	- "GANDI_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 2400)`)
		ew.writeln(`	- "GANDI_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/gandi`)

	case "gandiv5":
		// generated from: providers/dns/gandiv5/gandiv5.toml
		ew.writeln(`Configuration for Gandi Live DNS (v5).`)
		ew.writeln(`Code:	'gandiv5'`)
		ew.writeln(`Since:	'v0.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "GANDIV5_API_KEY":	API key (Deprecated)`)
		ew.writeln(`	- "GANDIV5_PERSONAL_ACCESS_TOKEN":	Personal Access Token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "GANDIV5_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "GANDIV5_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 20)`)
		ew.writeln(`	- "GANDIV5_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 1200)`)
		ew.writeln(`	- "GANDIV5_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/gandiv5`)

	case "gcloud":
		// generated from: providers/dns/gcloud/gcloud.toml
		ew.writeln(`Configuration for Google Cloud.`)
		ew.writeln(`Code:	'gcloud'`)
		ew.writeln(`Since:	'v0.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "Application Default Credentials":	[Documentation](https://cloud.google.com/docs/authentication/production#providing_credentials_to_your_application)`)
		ew.writeln(`	- "GCE_PROJECT":	Project name (by default, the project name is auto-detected by using the metadata service)`)
		ew.writeln(`	- "GCE_SERVICE_ACCOUNT":	Account`)
		ew.writeln(`	- "GCE_SERVICE_ACCOUNT_FILE":	Account file path`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "GCE_ALLOW_PRIVATE_ZONE":	Allows requested domain to be in private DNS zone, works only with a private ACME server (by default: false)`)
		ew.writeln(`	- "GCE_IMPERSONATE_SERVICE_ACCOUNT":	Service account email to impersonate`)
		ew.writeln(`	- "GCE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 5)`)
		ew.writeln(`	- "GCE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 180)`)
		ew.writeln(`	- "GCE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)
		ew.writeln(`	- "GCE_ZONE_ID":	Allows to skip the automatic detection of the zone`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/gcloud`)

	case "gcore":
		// generated from: providers/dns/gcore/gcore.toml
		ew.writeln(`Configuration for G-Core.`)
		ew.writeln(`Code:	'gcore'`)
		ew.writeln(`Since:	'v4.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "GCORE_PERMANENT_API_TOKEN":	Permanent API token (https://gcore.com/blog/permanent-api-token-explained/)`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "GCORE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "GCORE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 20)`)
		ew.writeln(`	- "GCORE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 360)`)
		ew.writeln(`	- "GCORE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/gcore`)

	case "gehirn":
		// generated from: providers/dns/gehirn/gehirn.toml
		ew.writeln(`Configuration for Gehirn.`)
		ew.writeln(`Code:	'gehirn'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "GEHIRN_TOKEN_ID":	Token ID`)
		ew.writeln(`	- "GEHIRN_TOKEN_SECRET":	Token secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "GEHIRN_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "GEHIRN_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "GEHIRN_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "GEHIRN_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/gehirn`)

	case "gigahostno":
		// generated from: providers/dns/gigahostno/gigahostno.toml
		ew.writeln(`Configuration for Gigahost.no.`)
		ew.writeln(`Code:	'gigahostno'`)
		ew.writeln(`Since:	'v4.29.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "GIGAHOSTNO_PASSWORD":	Password`)
		ew.writeln(`	- "GIGAHOSTNO_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "GIGAHOSTNO_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "GIGAHOSTNO_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "GIGAHOSTNO_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "GIGAHOSTNO_SECRET":	TOTP secret`)
		ew.writeln(`	- "GIGAHOSTNO_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/gigahostno`)

	case "glesys":
		// generated from: providers/dns/glesys/glesys.toml
		ew.writeln(`Configuration for Glesys.`)
		ew.writeln(`Code:	'glesys'`)
		ew.writeln(`Since:	'v0.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "GLESYS_API_KEY":	API key`)
		ew.writeln(`	- "GLESYS_API_USER":	API user`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "GLESYS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "GLESYS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 20)`)
		ew.writeln(`	- "GLESYS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 1200)`)
		ew.writeln(`	- "GLESYS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/glesys`)

	case "gname":
		// generated from: providers/dns/gname/gname.toml
		ew.writeln(`Configuration for Gname.`)
		ew.writeln(`Code:	'gname'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "GNAME_APP_ID":	App ID`)
		ew.writeln(`	- "GNAME_APP_KEY":	App key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "GNAME_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "GNAME_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "GNAME_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "GNAME_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/gname`)

	case "godaddy":
		// generated from: providers/dns/godaddy/godaddy.toml
		ew.writeln(`Configuration for Go Daddy.`)
		ew.writeln(`Code:	'godaddy'`)
		ew.writeln(`Since:	'v0.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "GODADDY_API_KEY":	API key`)
		ew.writeln(`	- "GODADDY_API_SECRET":	API secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "GODADDY_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "GODADDY_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "GODADDY_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "GODADDY_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/godaddy`)

	case "gravity":
		// generated from: providers/dns/gravity/gravity.toml
		ew.writeln(`Configuration for Gravity.`)
		ew.writeln(`Code:	'gravity'`)
		ew.writeln(`Since:	'v4.30.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "GRAVITY_PASSWORD":	Password`)
		ew.writeln(`	- "GRAVITY_SERVER_URL":	URL of the server`)
		ew.writeln(`	- "GRAVITY_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "GRAVITY_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "GRAVITY_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "GRAVITY_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "GRAVITY_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 1)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/gravity`)

	case "hetzner":
		// generated from: providers/dns/hetzner/hetzner.toml
		ew.writeln(`Configuration for Hetzner.`)
		ew.writeln(`Code:	'hetzner'`)
		ew.writeln(`Since:	'v3.7.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "HETZNER_API_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "HETZNER_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "HETZNER_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "HETZNER_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "HETZNER_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/hetzner`)

	case "hostingde":
		// generated from: providers/dns/hostingde/hostingde.toml
		ew.writeln(`Configuration for Hosting.de.`)
		ew.writeln(`Code:	'hostingde'`)
		ew.writeln(`Since:	'v1.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "HOSTINGDE_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "HOSTINGDE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "HOSTINGDE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "HOSTINGDE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "HOSTINGDE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)
		ew.writeln(`	- "HOSTINGDE_ZONE_NAME":	Zone name in ACE format`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/hostingde`)

	case "hostinger":
		// generated from: providers/dns/hostinger/hostinger.toml
		ew.writeln(`Configuration for Hostinger.`)
		ew.writeln(`Code:	'hostinger'`)
		ew.writeln(`Since:	'v4.27.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "HOSTINGER_API_TOKEN":	API Token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "HOSTINGER_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "HOSTINGER_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "HOSTINGER_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "HOSTINGER_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/hostinger`)

	case "hostingnl":
		// generated from: providers/dns/hostingnl/hostingnl.toml
		ew.writeln(`Configuration for Hosting.nl.`)
		ew.writeln(`Code:	'hostingnl'`)
		ew.writeln(`Since:	'v4.30.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "HOSTINGNL_API_KEY":	The API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "HOSTINGNL_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "HOSTINGNL_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "HOSTINGNL_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "HOSTINGNL_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/hostingnl`)

	case "hosttech":
		// generated from: providers/dns/hosttech/hosttech.toml
		ew.writeln(`Configuration for Hosttech.`)
		ew.writeln(`Code:	'hosttech'`)
		ew.writeln(`Since:	'v4.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "HOSTTECH_API_KEY":	API login`)
		ew.writeln(`	- "HOSTTECH_PASSWORD":	API password`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "HOSTTECH_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "HOSTTECH_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "HOSTTECH_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "HOSTTECH_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 3600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/hosttech`)

	case "hostup":
		// generated from: providers/dns/hostup/hostup.toml
		ew.writeln(`Configuration for HostUp.`)
		ew.writeln(`Code:	'hostup'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "HOSTUP_API_KEY":	API token (required scopes: read:dns, write:dns, read:domains)`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "HOSTUP_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "HOSTUP_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "HOSTUP_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "HOSTUP_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/hostup`)

	case "httpnet":
		// generated from: providers/dns/httpnet/httpnet.toml
		ew.writeln(`Configuration for http.net.`)
		ew.writeln(`Code:	'httpnet'`)
		ew.writeln(`Since:	'v4.15.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "HTTPNET_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "HTTPNET_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "HTTPNET_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "HTTPNET_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "HTTPNET_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)
		ew.writeln(`	- "HTTPNET_ZONE_NAME":	Zone name in ACE format`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/httpnet`)

	case "httpreq":
		// generated from: providers/dns/httpreq/httpreq.toml
		ew.writeln(`Configuration for HTTP request.`)
		ew.writeln(`Code:	'httpreq'`)
		ew.writeln(`Since:	'v2.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "HTTPREQ_ENDPOINT":	The URL of the server`)
		ew.writeln(`	- "HTTPREQ_MODE":	'RAW', none`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "HTTPREQ_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "HTTPREQ_PASSWORD":	Basic authentication password`)
		ew.writeln(`	- "HTTPREQ_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "HTTPREQ_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "HTTPREQ_USERNAME":	Basic authentication username`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/httpreq`)

	case "huaweicloud":
		// generated from: providers/dns/huaweicloud/huaweicloud.toml
		ew.writeln(`Configuration for Huawei Cloud.`)
		ew.writeln(`Code:	'huaweicloud'`)
		ew.writeln(`Since:	'v4.19'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "HUAWEICLOUD_ACCESS_KEY_ID":	Access key ID`)
		ew.writeln(`	- "HUAWEICLOUD_REGION":	Region`)
		ew.writeln(`	- "HUAWEICLOUD_SECRET_ACCESS_KEY":	Access Key secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "HUAWEICLOUD_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "HUAWEICLOUD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "HUAWEICLOUD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "HUAWEICLOUD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/huaweicloud`)

	case "hurricane":
		// generated from: providers/dns/hurricane/hurricane.toml
		ew.writeln(`Configuration for Hurricane Electric DNS.`)
		ew.writeln(`Code:	'hurricane'`)
		ew.writeln(`Since:	'v4.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "HURRICANE_TOKENS":	TXT record names and tokens`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "HURRICANE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "HURRICANE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "HURRICANE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation (Default: 300)`)
		ew.writeln(`	- "HURRICANE_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/hurricane`)

	case "hyperone":
		// generated from: providers/dns/hyperone/hyperone.toml
		ew.writeln(`Configuration for HyperOne.`)
		ew.writeln(`Code:	'hyperone'`)
		ew.writeln(`Since:	'v3.9.0'`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "HYPERONE_API_URL":	Allows to pass custom API Endpoint to be used in the challenge (default https://api.hyperone.com/v2)`)
		ew.writeln(`	- "HYPERONE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "HYPERONE_LOCATION_ID":	Specifies location (region) to be used in API calls. (default pl-waw-1)`)
		ew.writeln(`	- "HYPERONE_PASSPORT_LOCATION":	Allows to pass custom passport file location (default ~/.h1/passport.json)`)
		ew.writeln(`	- "HYPERONE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 60)`)
		ew.writeln(`	- "HYPERONE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 2)`)
		ew.writeln(`	- "HYPERONE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/hyperone`)

	case "ibmcloud":
		// generated from: providers/dns/ibmcloud/ibmcloud.toml
		ew.writeln(`Configuration for IBM Cloud (SoftLayer).`)
		ew.writeln(`Code:	'ibmcloud'`)
		ew.writeln(`Since:	'v4.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SOFTLAYER_API_KEY":	Classic Infrastructure API key`)
		ew.writeln(`	- "SOFTLAYER_USERNAME":	Username (IBM Cloud is {accountID}_{emailAddress})`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SOFTLAYER_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "SOFTLAYER_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "SOFTLAYER_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "SOFTLAYER_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/ibmcloud`)

	case "iijdpf":
		// generated from: providers/dns/iijdpf/iijdpf.toml
		ew.writeln(`Configuration for IIJ DNS Platform Service.`)
		ew.writeln(`Code:	'iijdpf'`)
		ew.writeln(`Since:	'v4.7.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "IIJ_DPF_API_TOKEN":	API token`)
		ew.writeln(`	- "IIJ_DPF_DPM_SERVICE_CODE":	IIJ Managed DNS Service's service code`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "IIJ_DPF_API_ENDPOINT":	API endpoint URL, defaults to https://api.dns-platform.jp/dpf/v1`)
		ew.writeln(`	- "IIJ_DPF_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 5)`)
		ew.writeln(`	- "IIJ_DPF_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 660)`)
		ew.writeln(`	- "IIJ_DPF_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/iijdpf`)

	case "infoblox":
		// generated from: providers/dns/infoblox/infoblox.toml
		ew.writeln(`Configuration for Infoblox.`)
		ew.writeln(`Code:	'infoblox'`)
		ew.writeln(`Since:	'v4.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "INFOBLOX_HOST":	Host URI`)
		ew.writeln(`	- "INFOBLOX_PASSWORD":	Account Password`)
		ew.writeln(`	- "INFOBLOX_USERNAME":	Account Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "INFOBLOX_CA_CERTIFICATE":	The path to the CA certificate (PEM encoded)`)
		ew.writeln(`	- "INFOBLOX_DNS_VIEW":	The view for the TXT records (Default: External)`)
		ew.writeln(`	- "INFOBLOX_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "INFOBLOX_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "INFOBLOX_PORT":	The port for the infoblox grid manager  (Default: 443)`)
		ew.writeln(`	- "INFOBLOX_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "INFOBLOX_SSL_VERIFY":	Whether or not to verify the TLS certificate  (Default: true)`)
		ew.writeln(`	- "INFOBLOX_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)
		ew.writeln(`	- "INFOBLOX_WAPI_VERSION":	The version of WAPI being used  (Default: 2.11)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/infoblox`)

	case "infomaniak":
		// generated from: providers/dns/infomaniak/infomaniak.toml
		ew.writeln(`Configuration for Infomaniak.`)
		ew.writeln(`Code:	'infomaniak'`)
		ew.writeln(`Since:	'v4.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "INFOMANIAK_ACCESS_TOKEN":	Access token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "INFOMANIAK_ENDPOINT":	https://api.infomaniak.com`)
		ew.writeln(`	- "INFOMANIAK_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "INFOMANIAK_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "INFOMANIAK_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "INFOMANIAK_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/infomaniak`)

	case "internetbs":
		// generated from: providers/dns/internetbs/internetbs.toml
		ew.writeln(`Configuration for Internet.bs.`)
		ew.writeln(`Code:	'internetbs'`)
		ew.writeln(`Since:	'v4.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "INTERNET_BS_API_KEY":	API key`)
		ew.writeln(`	- "INTERNET_BS_PASSWORD":	API password`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "INTERNET_BS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "INTERNET_BS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "INTERNET_BS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "INTERNET_BS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 3600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/internetbs`)

	case "inwx":
		// generated from: providers/dns/inwx/inwx.toml
		ew.writeln(`Configuration for INWX.`)
		ew.writeln(`Code:	'inwx'`)
		ew.writeln(`Since:	'v2.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "INWX_PASSWORD":	Password`)
		ew.writeln(`	- "INWX_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "INWX_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "INWX_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 360)`)
		ew.writeln(`	- "INWX_SANDBOX":	Activate the sandbox (boolean)`)
		ew.writeln(`	- "INWX_SHARED_SECRET":	shared secret related to 2FA`)
		ew.writeln(`	- "INWX_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/inwx`)

	case "ionos":
		// generated from: providers/dns/ionos/ionos.toml
		ew.writeln(`Configuration for Ionos.`)
		ew.writeln(`Code:	'ionos'`)
		ew.writeln(`Since:	'v4.2.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "IONOS_API_KEY":	API key '<prefix>.<secret>' https://developer.hosting.ionos.com/docs/getstarted`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "IONOS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "IONOS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "IONOS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 900)`)
		ew.writeln(`	- "IONOS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/ionos`)

	case "ionoscloud":
		// generated from: providers/dns/ionoscloud/ionoscloud.toml
		ew.writeln(`Configuration for Ionos Cloud.`)
		ew.writeln(`Code:	'ionoscloud'`)
		ew.writeln(`Since:	'v4.30.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "IONOSCLOUD_API_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "IONOSCLOUD_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "IONOSCLOUD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "IONOSCLOUD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "IONOSCLOUD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/ionoscloud`)

	case "ipv64":
		// generated from: providers/dns/ipv64/ipv64.toml
		ew.writeln(`Configuration for IPv64.`)
		ew.writeln(`Code:	'ipv64'`)
		ew.writeln(`Since:	'v4.13.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "IPV64_API_KEY":	Account API Key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "IPV64_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "IPV64_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "IPV64_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/ipv64`)

	case "ispconfig":
		// generated from: providers/dns/ispconfig/ispconfig.toml
		ew.writeln(`Configuration for ISPConfig 3.`)
		ew.writeln(`Code:	'ispconfig'`)
		ew.writeln(`Since:	'v4.31.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ISPCONFIG_PASSWORD":	Password`)
		ew.writeln(`	- "ISPCONFIG_SERVER_URL":	Server URL`)
		ew.writeln(`	- "ISPCONFIG_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ISPCONFIG_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ISPCONFIG_INSECURE_SKIP_VERIFY":	Whether to verify the API certificate`)
		ew.writeln(`	- "ISPCONFIG_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ISPCONFIG_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "ISPCONFIG_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/ispconfig`)

	case "ispconfigddns":
		// generated from: providers/dns/ispconfigddns/ispconfigddns.toml
		ew.writeln(`Configuration for ISPConfig 3 - Dynamic DNS (DDNS) Module.`)
		ew.writeln(`Code:	'ispconfigddns'`)
		ew.writeln(`Since:	'v4.31.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ISPCONFIG_DDNS_SERVER_URL":	API server URL (ex: https://panel.example.com:8080)`)
		ew.writeln(`	- "ISPCONFIG_DDNS_TOKEN":	DDNS API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ISPCONFIG_DDNS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ISPCONFIG_DDNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ISPCONFIG_DDNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "ISPCONFIG_DDNS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 3600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/ispconfigddns`)

	case "jdcloud":
		// generated from: providers/dns/jdcloud/jdcloud.toml
		ew.writeln(`Configuration for JD Cloud.`)
		ew.writeln(`Code:	'jdcloud'`)
		ew.writeln(`Since:	'v4.31.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "JDCLOUD_ACCESS_KEY_ID":	Access key ID`)
		ew.writeln(`	- "JDCLOUD_ACCESS_KEY_SECRET":	Access key secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "JDCLOUD_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "JDCLOUD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "JDCLOUD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "JDCLOUD_REGION_ID":	Region ID (Default: cn-north-1)`)
		ew.writeln(`	- "JDCLOUD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/jdcloud`)

	case "joker":
		// generated from: providers/dns/joker/joker.toml
		ew.writeln(`Configuration for Joker.`)
		ew.writeln(`Code:	'joker'`)
		ew.writeln(`Since:	'v2.6.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "JOKER_API_KEY":	API key (only with DMAPI mode)`)
		ew.writeln(`	- "JOKER_API_MODE":	'DMAPI' or 'SVC'. DMAPI is for resellers accounts. (Default: DMAPI)`)
		ew.writeln(`	- "JOKER_PASSWORD":	Joker.com password`)
		ew.writeln(`	- "JOKER_USERNAME":	Joker.com username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "JOKER_HTTP_TIMEOUT":	API request timeout in seconds (Default: 60)`)
		ew.writeln(`	- "JOKER_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "JOKER_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "JOKER_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60), only with 'SVC' mode`)
		ew.writeln(`	- "JOKER_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/joker`)

	case "katapult":
		// generated from: providers/dns/katapult/katapult.toml
		ew.writeln(`Configuration for Katapult.`)
		ew.writeln(`Code:	'katapult'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "KATAPULT_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "KATAPULT_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "KATAPULT_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "KATAPULT_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "KATAPULT_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/katapult`)

	case "keyhelp":
		// generated from: providers/dns/keyhelp/keyhelp.toml
		ew.writeln(`Configuration for KeyHelp.`)
		ew.writeln(`Code:	'keyhelp'`)
		ew.writeln(`Since:	'v4.26.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "KEYHELP_API_KEY":	API key`)
		ew.writeln(`	- "KEYHELP_BASE_URL":	Server URL`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "KEYHELP_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "KEYHELP_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "KEYHELP_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "KEYHELP_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/keyhelp`)

	case "leaseweb":
		// generated from: providers/dns/leaseweb/leaseweb.toml
		ew.writeln(`Configuration for Leaseweb.`)
		ew.writeln(`Code:	'leaseweb'`)
		ew.writeln(`Since:	'v4.32.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "LEASEWEB_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "LEASEWEB_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "LEASEWEB_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "LEASEWEB_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "LEASEWEB_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/leaseweb`)

	case "liara":
		// generated from: providers/dns/liara/liara.toml
		ew.writeln(`Configuration for Liara.`)
		ew.writeln(`Code:	'liara'`)
		ew.writeln(`Since:	'v4.10.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "LIARA_API_KEY":	The API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "LIARA_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "LIARA_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "LIARA_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "LIARA_TEAM_ID":	The team ID to access services in a team`)
		ew.writeln(`	- "LIARA_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 3600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/liara`)

	case "lightsail":
		// generated from: providers/dns/lightsail/lightsail.toml
		ew.writeln(`Configuration for Amazon Lightsail.`)
		ew.writeln(`Code:	'lightsail'`)
		ew.writeln(`Since:	'v0.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "AWS_ACCESS_KEY_ID":	Managed by the AWS client. Access key ID ('AWS_ACCESS_KEY_ID_FILE' is not supported, use 'AWS_SHARED_CREDENTIALS_FILE' instead)`)
		ew.writeln(`	- "AWS_SECRET_ACCESS_KEY":	Managed by the AWS client. Secret access key ('AWS_SECRET_ACCESS_KEY_FILE' is not supported, use 'AWS_SHARED_CREDENTIALS_FILE' instead)`)
		ew.writeln(`	- "DNS_ZONE":	Domain name of the DNS zone`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "AWS_SHARED_CREDENTIALS_FILE":	Managed by the AWS client. Shared credentials file.`)
		ew.writeln(`	- "LIGHTSAIL_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "LIGHTSAIL_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/lightsail`)

	case "limacity":
		// generated from: providers/dns/limacity/limacity.toml
		ew.writeln(`Configuration for Lima-City.`)
		ew.writeln(`Code:	'limacity'`)
		ew.writeln(`Since:	'v4.18.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "LIMACITY_API_KEY":	The API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "LIMACITY_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "LIMACITY_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 80)`)
		ew.writeln(`	- "LIMACITY_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 480)`)
		ew.writeln(`	- "LIMACITY_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 90)`)
		ew.writeln(`	- "LIMACITY_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/limacity`)

	case "linode":
		// generated from: providers/dns/linode/linode.toml
		ew.writeln(`Configuration for Linode (v4).`)
		ew.writeln(`Code:	'linode'`)
		ew.writeln(`Since:	'v1.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "LINODE_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "LINODE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "LINODE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 15)`)
		ew.writeln(`	- "LINODE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "LINODE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/linode`)

	case "liquidweb":
		// generated from: providers/dns/liquidweb/liquidweb.toml
		ew.writeln(`Configuration for Liquid Web.`)
		ew.writeln(`Code:	'liquidweb'`)
		ew.writeln(`Since:	'v3.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "LWAPI_PASSWORD":	Liquid Web API Password`)
		ew.writeln(`	- "LWAPI_USERNAME":	Liquid Web API Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "LWAPI_HTTP_TIMEOUT":	API request timeout in seconds (Default: 60)`)
		ew.writeln(`	- "LWAPI_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "LWAPI_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "LWAPI_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)
		ew.writeln(`	- "LWAPI_URL":	Liquid Web API endpoint`)
		ew.writeln(`	- "LWAPI_ZONE":	DNS Zone`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/liquidweb`)

	case "loopia":
		// generated from: providers/dns/loopia/loopia.toml
		ew.writeln(`Configuration for Loopia.`)
		ew.writeln(`Code:	'loopia'`)
		ew.writeln(`Since:	'v4.2.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "LOOPIA_API_PASSWORD":	API password`)
		ew.writeln(`	- "LOOPIA_API_USER":	API username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "LOOPIA_API_URL":	API endpoint. Ex: https://api.loopia.se/RPCSERV or https://api.loopia.rs/RPCSERV`)
		ew.writeln(`	- "LOOPIA_HTTP_TIMEOUT":	API request timeout in seconds (Default: 60)`)
		ew.writeln(`	- "LOOPIA_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2400)`)
		ew.writeln(`	- "LOOPIA_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "LOOPIA_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/loopia`)

	case "luadns":
		// generated from: providers/dns/luadns/luadns.toml
		ew.writeln(`Configuration for LuaDNS.`)
		ew.writeln(`Code:	'luadns'`)
		ew.writeln(`Since:	'v3.7.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "LUADNS_API_TOKEN":	API token`)
		ew.writeln(`	- "LUADNS_API_USERNAME":	Username (your email)`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "LUADNS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "LUADNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "LUADNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "LUADNS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/luadns`)

	case "mailinabox":
		// generated from: providers/dns/mailinabox/mailinabox.toml
		ew.writeln(`Configuration for Mail-in-a-Box.`)
		ew.writeln(`Code:	'mailinabox'`)
		ew.writeln(`Since:	'v4.16.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "MAILINABOX_BASE_URL":	Base API URL (ex: https://box.example.com)`)
		ew.writeln(`	- "MAILINABOX_EMAIL":	User email`)
		ew.writeln(`	- "MAILINABOX_PASSWORD":	User password`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "MAILINABOX_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "MAILINABOX_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 4)`)
		ew.writeln(`	- "MAILINABOX_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/mailinabox`)

	case "manageengine":
		// generated from: providers/dns/manageengine/manageengine.toml
		ew.writeln(`Configuration for ManageEngine CloudDNS.`)
		ew.writeln(`Code:	'manageengine'`)
		ew.writeln(`Since:	'v4.21.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "MANAGEENGINE_CLIENT_ID":	Client ID`)
		ew.writeln(`	- "MANAGEENGINE_CLIENT_SECRET":	Client Secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "MANAGEENGINE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "MANAGEENGINE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "MANAGEENGINE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/manageengine`)

	case "manual":
		// generated from: providers/dns/manual/manual.toml
		ew.writeln(`Configuration for Manual.`)
		ew.writeln(`Code:	'manual'`)
		ew.writeln(`Since:	'v0.3.0'`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "MANUAL_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "MANUAL_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/manual`)

	case "metaname":
		// generated from: providers/dns/metaname/metaname.toml
		ew.writeln(`Configuration for Metaname.`)
		ew.writeln(`Code:	'metaname'`)
		ew.writeln(`Since:	'v4.13.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "METANAME_ACCOUNT_REFERENCE":	The four-digit reference of a Metaname account`)
		ew.writeln(`	- "METANAME_API_KEY":	API Key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "METANAME_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "METANAME_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "METANAME_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/metaname`)

	case "metaregistrar":
		// generated from: providers/dns/metaregistrar/metaregistrar.toml
		ew.writeln(`Configuration for Metaregistrar.`)
		ew.writeln(`Code:	'metaregistrar'`)
		ew.writeln(`Since:	'v4.23.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "METAREGISTRAR_API_TOKEN":	The API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "METAREGISTRAR_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "METAREGISTRAR_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "METAREGISTRAR_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "METAREGISTRAR_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/metaregistrar`)

	case "mijnhost":
		// generated from: providers/dns/mijnhost/mijnhost.toml
		ew.writeln(`Configuration for mijn.host.`)
		ew.writeln(`Code:	'mijnhost'`)
		ew.writeln(`Since:	'v4.18.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "MIJNHOST_API_KEY":	The API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "MIJNHOST_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "MIJNHOST_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "MIJNHOST_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "MIJNHOST_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)
		ew.writeln(`	- "MIJNHOST_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/mijnhost`)

	case "mittwald":
		// generated from: providers/dns/mittwald/mittwald.toml
		ew.writeln(`Configuration for Mittwald.`)
		ew.writeln(`Code:	'mittwald'`)
		ew.writeln(`Since:	'v1.48.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "MITTWALD_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "MITTWALD_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "MITTWALD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "MITTWALD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "MITTWALD_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 120)`)
		ew.writeln(`	- "MITTWALD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/mittwald`)

	case "myaddr":
		// generated from: providers/dns/myaddr/myaddr.toml
		ew.writeln(`Configuration for myaddr.{tools,dev,io}.`)
		ew.writeln(`Code:	'myaddr'`)
		ew.writeln(`Since:	'v4.22.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "MYADDR_PRIVATE_KEYS_MAPPING":	Mapping between subdomains and private keys. The format is: '<subdomain1>:<private_key1>,<subdomain2>:<private_key2>,<subdomain3>:<private_key3>'`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "MYADDR_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "MYADDR_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "MYADDR_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "MYADDR_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 2)`)
		ew.writeln(`	- "MYADDR_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/myaddr`)

	case "mydnsjp":
		// generated from: providers/dns/mydnsjp/mydnsjp.toml
		ew.writeln(`Configuration for MyDNS.jp.`)
		ew.writeln(`Code:	'mydnsjp'`)
		ew.writeln(`Since:	'v1.2.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "MYDNSJP_MASTER_ID":	Master ID`)
		ew.writeln(`	- "MYDNSJP_PASSWORD":	Password`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "MYDNSJP_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "MYDNSJP_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "MYDNSJP_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/mydnsjp`)

	case "mythicbeasts":
		// generated from: providers/dns/mythicbeasts/mythicbeasts.toml
		ew.writeln(`Configuration for MythicBeasts.`)
		ew.writeln(`Code:	'mythicbeasts'`)
		ew.writeln(`Since:	'v0.3.7'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "MYTHICBEASTS_PASSWORD":	Password`)
		ew.writeln(`	- "MYTHICBEASTS_USERNAME":	User name`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "MYTHICBEASTS_API_ENDPOINT":	The endpoint for the API (must implement v2)`)
		ew.writeln(`	- "MYTHICBEASTS_AUTH_API_ENDPOINT":	The endpoint for Mythic Beasts' Authentication`)
		ew.writeln(`	- "MYTHICBEASTS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "MYTHICBEASTS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "MYTHICBEASTS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "MYTHICBEASTS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/mythicbeasts`)

	case "namecheap":
		// generated from: providers/dns/namecheap/namecheap.toml
		ew.writeln(`Configuration for Namecheap.`)
		ew.writeln(`Code:	'namecheap'`)
		ew.writeln(`Since:	'v0.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NAMECHEAP_API_KEY":	API key`)
		ew.writeln(`	- "NAMECHEAP_API_USER":	API user`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NAMECHEAP_HTTP_TIMEOUT":	API request timeout in seconds (Default: 60)`)
		ew.writeln(`	- "NAMECHEAP_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 15)`)
		ew.writeln(`	- "NAMECHEAP_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 3600)`)
		ew.writeln(`	- "NAMECHEAP_SANDBOX":	Activate the sandbox (boolean)`)
		ew.writeln(`	- "NAMECHEAP_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/namecheap`)

	case "namedotcom":
		// generated from: providers/dns/namedotcom/namedotcom.toml
		ew.writeln(`Configuration for Name.com.`)
		ew.writeln(`Code:	'namedotcom'`)
		ew.writeln(`Since:	'v0.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NAMECOM_API_TOKEN":	API token`)
		ew.writeln(`	- "NAMECOM_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NAMECOM_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "NAMECOM_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 20)`)
		ew.writeln(`	- "NAMECOM_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 900)`)
		ew.writeln(`	- "NAMECOM_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/namedotcom`)

	case "namesilo":
		// generated from: providers/dns/namesilo/namesilo.toml
		ew.writeln(`Configuration for Namesilo.`)
		ew.writeln(`Code:	'namesilo'`)
		ew.writeln(`Since:	'v2.7.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NAMESILO_API_KEY":	Client ID`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NAMESILO_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "NAMESILO_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60), it is better to set larger than 15 minutes`)
		ew.writeln(`	- "NAMESILO_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 3600), should be in [3600, 2592000]`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/namesilo`)

	case "namesurfer":
		// generated from: providers/dns/namesurfer/namesurfer.toml
		ew.writeln(`Configuration for FusionLayer NameSurfer.`)
		ew.writeln(`Code:	'namesurfer'`)
		ew.writeln(`Since:	'v4.32.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NAMESURFER_API_KEY":	API key name`)
		ew.writeln(`	- "NAMESURFER_API_SECRET":	API secret`)
		ew.writeln(`	- "NAMESURFER_BASE_URL":	The base URL of NameSurfer API (jsonrpc10) endpoint URL (e.g., https://foo.example.com:8443/API/NSService_10)`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NAMESURFER_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "NAMESURFER_INSECURE_SKIP_VERIFY":	Whether to verify the API certificate`)
		ew.writeln(`	- "NAMESURFER_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "NAMESURFER_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "NAMESURFER_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)
		ew.writeln(`	- "NAMESURFER_VIEW":	DNS view name (optional, default: empty string)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/namesurfer`)

	case "nearlyfreespeech":
		// generated from: providers/dns/nearlyfreespeech/nearlyfreespeech.toml
		ew.writeln(`Configuration for NearlyFreeSpeech.NET.`)
		ew.writeln(`Code:	'nearlyfreespeech'`)
		ew.writeln(`Since:	'v4.8.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NEARLYFREESPEECH_API_KEY":	API Key for API requests`)
		ew.writeln(`	- "NEARLYFREESPEECH_LOGIN":	Username for API requests`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NEARLYFREESPEECH_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "NEARLYFREESPEECH_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "NEARLYFREESPEECH_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "NEARLYFREESPEECH_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)
		ew.writeln(`	- "NEARLYFREESPEECH_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 3600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/nearlyfreespeech`)

	case "nederhost":
		// generated from: providers/dns/nederhost/nederhost.toml
		ew.writeln(`Configuration for NederHost.`)
		ew.writeln(`Code:	'nederhost'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NEDERHOST_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NEDERHOST_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "NEDERHOST_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "NEDERHOST_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "NEDERHOST_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/nederhost`)

	case "neodigit":
		// generated from: providers/dns/neodigit/neodigit.toml
		ew.writeln(`Configuration for Neodigit.`)
		ew.writeln(`Code:	'neodigit'`)
		ew.writeln(`Since:	'v4.30.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NEODIGIT_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NEODIGIT_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "NEODIGIT_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "NEODIGIT_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 300)`)
		ew.writeln(`	- "NEODIGIT_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/neodigit`)

	case "netcup":
		// generated from: providers/dns/netcup/netcup.toml
		ew.writeln(`Configuration for Netcup.`)
		ew.writeln(`Code:	'netcup'`)
		ew.writeln(`Since:	'v1.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NETCUP_API_KEY":	API key`)
		ew.writeln(`	- "NETCUP_API_PASSWORD":	API password`)
		ew.writeln(`	- "NETCUP_CUSTOMER_NUMBER":	Customer number`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NETCUP_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "NETCUP_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 30)`)
		ew.writeln(`	- "NETCUP_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 900)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/netcup`)

	case "netlify":
		// generated from: providers/dns/netlify/netlify.toml
		ew.writeln(`Configuration for Netlify.`)
		ew.writeln(`Code:	'netlify'`)
		ew.writeln(`Since:	'v3.7.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NETLIFY_TOKEN":	Token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NETLIFY_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "NETLIFY_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "NETLIFY_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "NETLIFY_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/netlify`)

	case "netnod":
		// generated from: providers/dns/netnod/netnod.toml
		ew.writeln(`Configuration for Netnod.`)
		ew.writeln(`Code:	'netnod'`)
		ew.writeln(`Since:	'v4.34.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NETNOD_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NETNOD_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "NETNOD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "NETNOD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "NETNOD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/netnod`)

	case "ngenix":
		// generated from: providers/dns/ngenix/ngenix.toml
		ew.writeln(`Configuration for Ngenix.`)
		ew.writeln(`Code:	'ngenix'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NGENIX_CUSTOMER_ID":	Customer ID`)
		ew.writeln(`	- "NGENIX_TOKEN":	API token`)
		ew.writeln(`	- "NGENIX_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NGENIX_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "NGENIX_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 20)`)
		ew.writeln(`	- "NGENIX_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/ngenix`)

	case "nicmanager":
		// generated from: providers/dns/nicmanager/nicmanager.toml
		ew.writeln(`Configuration for Nicmanager.`)
		ew.writeln(`Code:	'nicmanager'`)
		ew.writeln(`Since:	'v4.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NICMANAGER_API_EMAIL":	Email-based login`)
		ew.writeln(`	- "NICMANAGER_API_LOGIN":	Login, used for Username-based login`)
		ew.writeln(`	- "NICMANAGER_API_PASSWORD":	Password, always required`)
		ew.writeln(`	- "NICMANAGER_API_USERNAME":	Username, used for Username-based login`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NICMANAGER_API_MODE":	mode: 'anycast' or 'zones' (for FreeDNS) (default: 'anycast')`)
		ew.writeln(`	- "NICMANAGER_API_OTP":	TOTP Secret (optional)`)
		ew.writeln(`	- "NICMANAGER_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "NICMANAGER_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "NICMANAGER_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 300)`)
		ew.writeln(`	- "NICMANAGER_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 900)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/nicmanager`)

	case "nicru":
		// generated from: providers/dns/nicru/nicru.toml
		ew.writeln(`Configuration for RU CENTER.`)
		ew.writeln(`Code:	'nicru'`)
		ew.writeln(`Since:	'v4.24.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NICRU_PASSWORD":	Password for an account in RU CENTER`)
		ew.writeln(`	- "NICRU_SECRET":	Secret for application in DNS-hosting RU CENTER`)
		ew.writeln(`	- "NICRU_SERVICE_ID":	Service ID for application in DNS-hosting RU CENTER`)
		ew.writeln(`	- "NICRU_SERVICE_NAME":	Service Name for DNS-hosting RU CENTER`)
		ew.writeln(`	- "NICRU_USER":	Agreement for an account in RU CENTER`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NICRU_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 60)`)
		ew.writeln(`	- "NICRU_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 600)`)
		ew.writeln(`	- "NICRU_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 30)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/nicru`)

	case "nifcloud":
		// generated from: providers/dns/nifcloud/nifcloud.toml
		ew.writeln(`Configuration for NIFCloud.`)
		ew.writeln(`Code:	'nifcloud'`)
		ew.writeln(`Since:	'v1.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NIFCLOUD_ACCESS_KEY_ID":	Access key`)
		ew.writeln(`	- "NIFCLOUD_SECRET_ACCESS_KEY":	Secret access key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NIFCLOUD_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "NIFCLOUD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "NIFCLOUD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "NIFCLOUD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/nifcloud`)

	case "njalla":
		// generated from: providers/dns/njalla/njalla.toml
		ew.writeln(`Configuration for Njalla.`)
		ew.writeln(`Code:	'njalla'`)
		ew.writeln(`Since:	'v4.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NJALLA_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NJALLA_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "NJALLA_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "NJALLA_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "NJALLA_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/njalla`)

	case "nodion":
		// generated from: providers/dns/nodion/nodion.toml
		ew.writeln(`Configuration for Nodion.`)
		ew.writeln(`Code:	'nodion'`)
		ew.writeln(`Since:	'v4.11.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NODION_API_TOKEN":	The API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NODION_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "NODION_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "NODION_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "NODION_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/nodion`)

	case "ns1":
		// generated from: providers/dns/ns1/ns1.toml
		ew.writeln(`Configuration for NS1.`)
		ew.writeln(`Code:	'ns1'`)
		ew.writeln(`Since:	'v0.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "NS1_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "NS1_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "NS1_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "NS1_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "NS1_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/ns1`)

	case "octenium":
		// generated from: providers/dns/octenium/octenium.toml
		ew.writeln(`Configuration for Octenium.`)
		ew.writeln(`Code:	'octenium'`)
		ew.writeln(`Since:	'v4.27.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "OCTENIUM_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "OCTENIUM_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "OCTENIUM_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "OCTENIUM_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "OCTENIUM_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/octenium`)

	case "omglol":
		// generated from: providers/dns/omglol/omglol.toml
		ew.writeln(`Configuration for omg.lol.`)
		ew.writeln(`Code:	'omglol'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "OMGLOL_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "OMGLOL_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "OMGLOL_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "OMGLOL_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "OMGLOL_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/omglol`)

	case "onecloudru":
		// generated from: providers/dns/onecloudru/onecloudru.toml
		ew.writeln(`Configuration for 1cloud.ru.`)
		ew.writeln(`Code:	'onecloudru'`)
		ew.writeln(`Since:	'v4.34.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ONECLOUDRU_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ONECLOUDRU_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ONECLOUDRU_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ONECLOUDRU_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "ONECLOUDRU_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/onecloudru`)

	case "onlinenet":
		// generated from: providers/dns/onlinenet/onlinenet.toml
		ew.writeln(`Configuration for Online.net.`)
		ew.writeln(`Code:	'onlinenet'`)
		ew.writeln(`Since:	'v4.34.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ONLINENET_API_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ONLINENET_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ONLINENET_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 15)`)
		ew.writeln(`	- "ONLINENET_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 240)`)
		ew.writeln(`	- "ONLINENET_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/onlinenet`)

	case "oraclecloud":
		// generated from: providers/dns/oraclecloud/oraclecloud.toml
		ew.writeln(`Configuration for Oracle Cloud.`)
		ew.writeln(`Code:	'oraclecloud'`)
		ew.writeln(`Since:	'v2.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "OCI_COMPARTMENT_OCID":	Compartment OCID`)
		ew.writeln(`	- "OCI_FINGERPRINT":	Public key fingerprint (ignored if 'OCI_AUTH_TYPE' is not empty)`)
		ew.writeln(`	- "OCI_PRIVATE_KEY_PASSWORD":	Private key password (ignored if 'OCI_AUTH_TYPE' is not empty)`)
		ew.writeln(`	- "OCI_PRIVATE_KEY_PATH":	Private key file (ignored if 'OCI_AUTH_TYPE' is not empty)`)
		ew.writeln(`	- "OCI_REGION":	Region (it can be empty if 'OCI_AUTH_TYPE' is not empty).`)
		ew.writeln(`	- "OCI_TENANCY_OCID":	Tenancy OCID (ignored if 'OCI_AUTH_TYPE' is not empty)`)
		ew.writeln(`	- "OCI_USER_OCID":	User OCID (ignored if 'OCI_AUTH_TYPE' is not empty)`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "OCI_AUTH_TYPE":	Authorization type. Possible values: 'instance_principal', 'user_principal', ''. (Default: '')`)
		ew.writeln(`	- "OCI_CONFIG_FILE":	Path to the configuration file. (only for 'OCI_AUTH_TYPE=user_principal')`)
		ew.writeln(`	- "OCI_HTTP_TIMEOUT":	API request timeout in seconds (Default: 60)`)
		ew.writeln(`	- "OCI_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "OCI_PROFILE":	Profile name. (only for 'OCI_AUTH_TYPE=user_principal')`)
		ew.writeln(`	- "OCI_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "OCI_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)
		ew.writeln(`	- "TF_VAR_fingerprint":	Alias on 'OCI_FINGERPRINT'`)
		ew.writeln(`	- "TF_VAR_private_key_path":	Alias on 'OCI_PRIVATE_KEY_PATH'`)
		ew.writeln(`	- "TF_VAR_region":	Alias on 'OCI_REGION'`)
		ew.writeln(`	- "TF_VAR_tenancy_ocid":	Alias on 'OCI_TENANCY_OCID'`)
		ew.writeln(`	- "TF_VAR_user_ocid":	Alias on 'OCI_USER_OCID'`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/oraclecloud`)

	case "otc":
		// generated from: providers/dns/otc/otc.toml
		ew.writeln(`Configuration for Open Telekom Cloud.`)
		ew.writeln(`Code:	'otc'`)
		ew.writeln(`Since:	'v0.4.1'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "OTC_DOMAIN_NAME":	Domain name`)
		ew.writeln(`	- "OTC_PASSWORD":	Password`)
		ew.writeln(`	- "OTC_PROJECT_NAME":	Project name`)
		ew.writeln(`	- "OTC_USER_NAME":	User name`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "OTC_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "OTC_IDENTITY_ENDPOINT":	Identity endpoint URL (default: https://iam.eu-de.otc.t-systems.com:443/v3/auth/tokens)`)
		ew.writeln(`	- "OTC_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "OTC_PRIVATE_ZONE":	Set to true to use private zones only (default: use public zones only)`)
		ew.writeln(`	- "OTC_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "OTC_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)
		ew.writeln(`	- "OTC_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/otc`)

	case "ovh":
		// generated from: providers/dns/ovh/ovh.toml
		ew.writeln(`Configuration for OVH.`)
		ew.writeln(`Code:	'ovh'`)
		ew.writeln(`Since:	'v0.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "OVH_ACCESS_TOKEN":	Access token`)
		ew.writeln(`	- "OVH_APPLICATION_KEY":	Application key (Application Key authentication)`)
		ew.writeln(`	- "OVH_APPLICATION_SECRET":	Application secret (Application Key authentication)`)
		ew.writeln(`	- "OVH_CLIENT_ID":	Client ID (OAuth2)`)
		ew.writeln(`	- "OVH_CLIENT_SECRET":	Client secret (OAuth2)`)
		ew.writeln(`	- "OVH_CONSUMER_KEY":	Consumer key (Application Key authentication)`)
		ew.writeln(`	- "OVH_ENDPOINT":	Endpoint URL (ovh-eu or ovh-ca)`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "OVH_HTTP_TIMEOUT":	API request timeout in seconds (Default: 180)`)
		ew.writeln(`	- "OVH_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "OVH_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "OVH_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/ovh`)

	case "pdns":
		// generated from: providers/dns/pdns/pdns.toml
		ew.writeln(`Configuration for PowerDNS.`)
		ew.writeln(`Code:	'pdns'`)
		ew.writeln(`Since:	'v0.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "PDNS_API_KEY":	API key`)
		ew.writeln(`	- "PDNS_API_URL":	API URL`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "PDNS_API_VERSION":	Skip API version autodetection and use the provided version number.`)
		ew.writeln(`	- "PDNS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "PDNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "PDNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "PDNS_SERVER_NAME":	Name of the server in the URL, 'localhost' by default`)
		ew.writeln(`	- "PDNS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/pdns`)

	case "plesk":
		// generated from: providers/dns/plesk/plesk.toml
		ew.writeln(`Configuration for plesk.com.`)
		ew.writeln(`Code:	'plesk'`)
		ew.writeln(`Since:	'v4.11.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "PLESK_PASSWORD":	API password`)
		ew.writeln(`	- "PLESK_SERVER_BASE_URL":	Base URL of the server (ex: https://plesk.myserver.com:8443)`)
		ew.writeln(`	- "PLESK_USERNAME":	API username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "PLESK_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "PLESK_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "PLESK_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "PLESK_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/plesk`)

	case "pointdns":
		// generated from: providers/dns/pointdns/pointdns.toml
		ew.writeln(`Configuration for PointDNS/PointHQ.`)
		ew.writeln(`Code:	'pointdns'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "POINTDNS_PASSWORD":	Password`)
		ew.writeln(`	- "POINTDNS_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "POINTDNS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "POINTDNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "POINTDNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "POINTDNS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/pointdns`)

	case "porkbun":
		// generated from: providers/dns/porkbun/porkbun.toml
		ew.writeln(`Configuration for Porkbun.`)
		ew.writeln(`Code:	'porkbun'`)
		ew.writeln(`Since:	'v4.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "PORKBUN_API_KEY":	API key`)
		ew.writeln(`	- "PORKBUN_SECRET_API_KEY":	secret API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "PORKBUN_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "PORKBUN_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "PORKBUN_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 600)`)
		ew.writeln(`	- "PORKBUN_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/porkbun`)

	case "rackspace":
		// generated from: providers/dns/rackspace/rackspace.toml
		ew.writeln(`Configuration for Rackspace.`)
		ew.writeln(`Code:	'rackspace'`)
		ew.writeln(`Since:	'v0.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "RACKSPACE_API_KEY":	API key`)
		ew.writeln(`	- "RACKSPACE_USER":	API user`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "RACKSPACE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "RACKSPACE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 3)`)
		ew.writeln(`	- "RACKSPACE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "RACKSPACE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/rackspace`)

	case "rage4":
		// generated from: providers/dns/rage4/rage4.toml
		ew.writeln(`Configuration for Rage4.`)
		ew.writeln(`Code:	'rage4'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "RAGE4_PASSWORD":	Password`)
		ew.writeln(`	- "RAGE4_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "RAGE4_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "RAGE4_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "RAGE4_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "RAGE4_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/rage4`)

	case "rainyun":
		// generated from: providers/dns/rainyun/rainyun.toml
		ew.writeln(`Configuration for Rain Yun/雨云.`)
		ew.writeln(`Code:	'rainyun'`)
		ew.writeln(`Since:	'v4.21.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "RAINYUN_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "RAINYUN_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "RAINYUN_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "RAINYUN_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "RAINYUN_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/rainyun`)

	case "rcodezero":
		// generated from: providers/dns/rcodezero/rcodezero.toml
		ew.writeln(`Configuration for RcodeZero.`)
		ew.writeln(`Code:	'rcodezero'`)
		ew.writeln(`Since:	'v4.13'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "RCODEZERO_API_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "RCODEZERO_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "RCODEZERO_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "RCODEZERO_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 240)`)
		ew.writeln(`	- "RCODEZERO_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/rcodezero`)

	case "regfish":
		// generated from: providers/dns/regfish/regfish.toml
		ew.writeln(`Configuration for Regfish.`)
		ew.writeln(`Code:	'regfish'`)
		ew.writeln(`Since:	'v4.20.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "REGFISH_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "REGFISH_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "REGFISH_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "REGFISH_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "REGFISH_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/regfish`)

	case "regru":
		// generated from: providers/dns/regru/regru.toml
		ew.writeln(`Configuration for reg.ru.`)
		ew.writeln(`Code:	'regru'`)
		ew.writeln(`Since:	'v3.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "REGRU_PASSWORD":	API password`)
		ew.writeln(`	- "REGRU_USERNAME":	API username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "REGRU_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "REGRU_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "REGRU_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "REGRU_TLS_CERT":	authentication certificate`)
		ew.writeln(`	- "REGRU_TLS_KEY":	authentication private key`)
		ew.writeln(`	- "REGRU_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/regru`)

	case "rimuhosting":
		// generated from: providers/dns/rimuhosting/rimuhosting.toml
		ew.writeln(`Configuration for RimuHosting.`)
		ew.writeln(`Code:	'rimuhosting'`)
		ew.writeln(`Since:	'v0.3.5'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "RIMUHOSTING_API_KEY":	User API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "RIMUHOSTING_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "RIMUHOSTING_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "RIMUHOSTING_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "RIMUHOSTING_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 3600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/rimuhosting`)

	case "route53":
		// generated from: providers/dns/route53/route53.toml
		ew.writeln(`Configuration for Amazon Route 53.`)
		ew.writeln(`Code:	'route53'`)
		ew.writeln(`Since:	'v0.3.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "AWS_ACCESS_KEY_ID":	Managed by the AWS client. Access key ID ('AWS_ACCESS_KEY_ID_FILE' is not supported, use 'AWS_SHARED_CREDENTIALS_FILE' instead)`)
		ew.writeln(`	- "AWS_ASSUME_ROLE_ARN":	Managed by the AWS Role ARN ('AWS_ASSUME_ROLE_ARN_FILE' is not supported)`)
		ew.writeln(`	- "AWS_EXTERNAL_ID":	Managed by STS AssumeRole API operation ('AWS_EXTERNAL_ID_FILE' is not supported)`)
		ew.writeln(`	- "AWS_HOSTED_ZONE_ID":	Override the hosted zone ID.`)
		ew.writeln(`	- "AWS_PROFILE":	Managed by the AWS client ('AWS_PROFILE_FILE' is not supported)`)
		ew.writeln(`	- "AWS_REGION":	Managed by the AWS client ('AWS_REGION_FILE' is not supported)`)
		ew.writeln(`	- "AWS_SDK_LOAD_CONFIG":	Managed by the AWS client. Retrieve the region from the CLI config file ('AWS_SDK_LOAD_CONFIG_FILE' is not supported)`)
		ew.writeln(`	- "AWS_SECRET_ACCESS_KEY":	Managed by the AWS client. Secret access key ('AWS_SECRET_ACCESS_KEY_FILE' is not supported, use 'AWS_SHARED_CREDENTIALS_FILE' instead)`)
		ew.writeln(`	- "AWS_WAIT_FOR_RECORD_SETS_CHANGED":	Wait for changes to be INSYNC (it can be unstable)`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "AWS_MAX_RETRIES":	The number of maximum returns the service will use to make an individual API request`)
		ew.writeln(`	- "AWS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 4)`)
		ew.writeln(`	- "AWS_PRIVATE_ZONE":	Set to true to use private zones only (default: use public zones only)`)
		ew.writeln(`	- "AWS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "AWS_SHARED_CREDENTIALS_FILE":	Managed by the AWS client. Shared credentials file.`)
		ew.writeln(`	- "AWS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 10)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/route53`)

	case "safedns":
		// generated from: providers/dns/safedns/safedns.toml
		ew.writeln(`Configuration for ANS SafeDNS.`)
		ew.writeln(`Code:	'safedns'`)
		ew.writeln(`Since:	'v4.6.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SAFEDNS_AUTH_TOKEN":	Authentication token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SAFEDNS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "SAFEDNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "SAFEDNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "SAFEDNS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/safedns`)

	case "sakuracloud":
		// generated from: providers/dns/sakuracloud/sakuracloud.toml
		ew.writeln(`Configuration for Sakura Cloud.`)
		ew.writeln(`Code:	'sakuracloud'`)
		ew.writeln(`Since:	'v1.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SAKURACLOUD_ACCESS_TOKEN":	Access token`)
		ew.writeln(`	- "SAKURACLOUD_ACCESS_TOKEN_SECRET":	Access token secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SAKURACLOUD_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "SAKURACLOUD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "SAKURACLOUD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "SAKURACLOUD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/sakuracloud`)

	case "scaleway":
		// generated from: providers/dns/scaleway/scaleway.toml
		ew.writeln(`Configuration for Scaleway.`)
		ew.writeln(`Code:	'scaleway'`)
		ew.writeln(`Since:	'v3.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SCW_PROJECT_ID":	Project to use (optional)`)
		ew.writeln(`	- "SCW_SECRET_KEY":	Secret key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SCW_ACCESS_KEY":	Access key`)
		ew.writeln(`	- "SCW_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "SCW_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "SCW_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "SCW_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/scaleway`)

	case "scannet":
		// generated from: providers/dns/scannet/scannet.toml
		ew.writeln(`Configuration for ScanNet.`)
		ew.writeln(`Code:	'scannet'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SCANNET_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SCANNET_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "SCANNET_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "SCANNET_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "SCANNET_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/scannet`)

	case "selectel":
		// generated from: providers/dns/selectel/selectel.toml
		ew.writeln(`Configuration for Selectel.`)
		ew.writeln(`Code:	'selectel'`)
		ew.writeln(`Since:	'v1.2.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SELECTEL_API_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SELECTEL_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "SELECTEL_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "SELECTEL_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "SELECTEL_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/selectel`)

	case "selectelv2":
		// generated from: providers/dns/selectelv2/selectelv2.toml
		ew.writeln(`Configuration for Selectel v2.`)
		ew.writeln(`Code:	'selectelv2'`)
		ew.writeln(`Since:	'v4.17.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SELECTELV2_ACCOUNT_ID":	Selectel account ID (INT)`)
		ew.writeln(`	- "SELECTELV2_PASSWORD":	Openstack username's password`)
		ew.writeln(`	- "SELECTELV2_PROJECT_ID":	Cloud project ID (UUID)`)
		ew.writeln(`	- "SELECTELV2_USERNAME":	Openstack username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SELECTELV2_AUTH_REGION":	Location for auth endpoint like ResellAPI or Keystone (default: 'ru-1')`)
		ew.writeln(`	- "SELECTELV2_AUTH_URL":	Identity endpoint (default: 'https://cloud.api.selcloud.ru/identity/v3/')`)
		ew.writeln(`	- "SELECTELV2_BASE_URL":	API endpoint URL`)
		ew.writeln(`	- "SELECTELV2_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "SELECTELV2_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 5)`)
		ew.writeln(`	- "SELECTELV2_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "SELECTELV2_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)
		ew.writeln(`	- "SELECTELV2_USER_DOMAIN_NAME":	To specify the domain name (account ID) where the user is located. (default: SELECTELV2_ACCOUNT_ID)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/selectelv2`)

	case "selfhostde":
		// generated from: providers/dns/selfhostde/selfhostde.toml
		ew.writeln(`Configuration for SelfHost.(de|eu).`)
		ew.writeln(`Code:	'selfhostde'`)
		ew.writeln(`Since:	'v4.19.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SELFHOSTDE_PASSWORD":	Password`)
		ew.writeln(`	- "SELFHOSTDE_RECORDS_MAPPING":	Record IDs mapping with domains (ex: example.com:123:456,example.org:789,foo.example.com:147)`)
		ew.writeln(`	- "SELFHOSTDE_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SELFHOSTDE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "SELFHOSTDE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 30)`)
		ew.writeln(`	- "SELFHOSTDE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 240)`)
		ew.writeln(`	- "SELFHOSTDE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/selfhostde`)

	case "servercow":
		// generated from: providers/dns/servercow/servercow.toml
		ew.writeln(`Configuration for Servercow.`)
		ew.writeln(`Code:	'servercow'`)
		ew.writeln(`Since:	'v3.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SERVERCOW_PASSWORD":	API password`)
		ew.writeln(`	- "SERVERCOW_USERNAME":	API username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SERVERCOW_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "SERVERCOW_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "SERVERCOW_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "SERVERCOW_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/servercow`)

	case "shellrent":
		// generated from: providers/dns/shellrent/shellrent.toml
		ew.writeln(`Configuration for Shellrent.`)
		ew.writeln(`Code:	'shellrent'`)
		ew.writeln(`Since:	'v4.16.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SHELLRENT_TOKEN":	Token`)
		ew.writeln(`	- "SHELLRENT_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SHELLRENT_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "SHELLRENT_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "SHELLRENT_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 300)`)
		ew.writeln(`	- "SHELLRENT_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 3600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/shellrent`)

	case "simply":
		// generated from: providers/dns/simply/simply.toml
		ew.writeln(`Configuration for Simply.com.`)
		ew.writeln(`Code:	'simply'`)
		ew.writeln(`Since:	'v4.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SIMPLY_ACCOUNT_NAME":	Account name`)
		ew.writeln(`	- "SIMPLY_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SIMPLY_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "SIMPLY_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "SIMPLY_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 300)`)
		ew.writeln(`	- "SIMPLY_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/simply`)

	case "sonic":
		// generated from: providers/dns/sonic/sonic.toml
		ew.writeln(`Configuration for Sonic.`)
		ew.writeln(`Code:	'sonic'`)
		ew.writeln(`Since:	'v4.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SONIC_API_KEY":	API Key`)
		ew.writeln(`	- "SONIC_USER_ID":	User ID`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SONIC_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "SONIC_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "SONIC_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "SONIC_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)
		ew.writeln(`	- "SONIC_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/sonic`)

	case "spaceship":
		// generated from: providers/dns/spaceship/spaceship.toml
		ew.writeln(`Configuration for Spaceship.`)
		ew.writeln(`Code:	'spaceship'`)
		ew.writeln(`Since:	'v4.22.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SPACESHIP_API_KEY":	API key`)
		ew.writeln(`	- "SPACESHIP_API_SECRET":	API secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SPACESHIP_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "SPACESHIP_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "SPACESHIP_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "SPACESHIP_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/spaceship`)

	case "stackpath":
		// generated from: providers/dns/stackpath/stackpath.toml
		ew.writeln(`Configuration for Stackpath (Deprecated).`)
		ew.writeln(`Code:	'stackpath'`)
		ew.writeln(`Since:	'v1.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "STACKPATH_CLIENT_ID":	Client ID`)
		ew.writeln(`	- "STACKPATH_CLIENT_SECRET":	Client secret`)
		ew.writeln(`	- "STACKPATH_STACK_ID":	Stack ID`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "STACKPATH_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "STACKPATH_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "STACKPATH_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/stackpath`)

	case "syse":
		// generated from: providers/dns/syse/syse.toml
		ew.writeln(`Configuration for Syse.`)
		ew.writeln(`Code:	'syse'`)
		ew.writeln(`Since:	'v4.30.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SYSE_CREDENTIALS":	Comma-separated list of 'zone:password' credential pairs`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "SYSE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "SYSE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "SYSE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 1200)`)
		ew.writeln(`	- "SYSE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/syse`)

	case "technitium":
		// generated from: providers/dns/technitium/technitium.toml
		ew.writeln(`Configuration for Technitium.`)
		ew.writeln(`Code:	'technitium'`)
		ew.writeln(`Since:	'v4.20.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "TECHNITIUM_API_TOKEN":	API token`)
		ew.writeln(`	- "TECHNITIUM_SERVER_BASE_URL":	Server base URL`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "TECHNITIUM_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "TECHNITIUM_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "TECHNITIUM_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "TECHNITIUM_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/technitium`)

	case "tele3":
		// generated from: providers/dns/tele3/tele3.toml
		ew.writeln(`Configuration for Tele3.`)
		ew.writeln(`Code:	'tele3'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "TELE3_KEY":	Key`)
		ew.writeln(`	- "TELE3_SECRET":	Secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "TELE3_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "TELE3_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "TELE3_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "TELE3_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/tele3`)

	case "tencentcloud":
		// generated from: providers/dns/tencentcloud/tencentcloud.toml
		ew.writeln(`Configuration for Tencent Cloud DNS.`)
		ew.writeln(`Code:	'tencentcloud'`)
		ew.writeln(`Since:	'v4.6.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "TENCENTCLOUD_SECRET_ID":	Access key ID`)
		ew.writeln(`	- "TENCENTCLOUD_SECRET_KEY":	Access Key secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "TENCENTCLOUD_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "TENCENTCLOUD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "TENCENTCLOUD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "TENCENTCLOUD_REGION":	Region`)
		ew.writeln(`	- "TENCENTCLOUD_SESSION_TOKEN":	Access Key token`)
		ew.writeln(`	- "TENCENTCLOUD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/tencentcloud`)

	case "timewebcloud":
		// generated from: providers/dns/timewebcloud/timewebcloud.toml
		ew.writeln(`Configuration for Timeweb Cloud.`)
		ew.writeln(`Code:	'timewebcloud'`)
		ew.writeln(`Since:	'v4.20.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "TIMEWEBCLOUD_AUTH_TOKEN":	Authentication token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "TIMEWEBCLOUD_HTTP_TIMEOUT":	API request timeout in seconds (Default: 10)`)
		ew.writeln(`	- "TIMEWEBCLOUD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "TIMEWEBCLOUD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/timewebcloud`)

	case "todaynic":
		// generated from: providers/dns/todaynic/todaynic.toml
		ew.writeln(`Configuration for TodayNIC/时代互联.`)
		ew.writeln(`Code:	'todaynic'`)
		ew.writeln(`Since:	'v4.32.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "TODAYNIC_API_KEY":	API key`)
		ew.writeln(`	- "TODAYNIC_AUTH_USER_ID":	account ID`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "TODAYNIC_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "TODAYNIC_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "TODAYNIC_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "TODAYNIC_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/todaynic`)

	case "transip":
		// generated from: providers/dns/transip/transip.toml
		ew.writeln(`Configuration for TransIP.`)
		ew.writeln(`Code:	'transip'`)
		ew.writeln(`Since:	'v2.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "TRANSIP_ACCOUNT_NAME":	Account name`)
		ew.writeln(`	- "TRANSIP_PRIVATE_KEY_PATH":	Private key path`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "TRANSIP_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "TRANSIP_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "TRANSIP_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 600)`)
		ew.writeln(`	- "TRANSIP_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 10)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/transip`)

	case "ucloud":
		// generated from: providers/dns/ucloud/ucloud.toml
		ew.writeln(`Configuration for UCloud.`)
		ew.writeln(`Code:	'ucloud'`)
		ew.writeln(`Since:	'v4.34.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "UCLOUD_PRIVATE_KEY":	Private key`)
		ew.writeln(`	- "UCLOUD_PUBLIC_KEY":	Public key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "UCLOUD_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "UCLOUD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "UCLOUD_PROJECT_ID":	Project ID`)
		ew.writeln(`	- "UCLOUD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "UCLOUD_REGION":	Region`)
		ew.writeln(`	- "UCLOUD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/ucloud`)

	case "ultradns":
		// generated from: providers/dns/ultradns/ultradns.toml
		ew.writeln(`Configuration for Ultradns.`)
		ew.writeln(`Code:	'ultradns'`)
		ew.writeln(`Since:	'v4.10.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ULTRADNS_PASSWORD":	API Password`)
		ew.writeln(`	- "ULTRADNS_USERNAME":	API Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ULTRADNS_ENDPOINT":	API endpoint URL, defaults to https://api.ultradns.com/`)
		ew.writeln(`	- "ULTRADNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 4)`)
		ew.writeln(`	- "ULTRADNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "ULTRADNS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/ultradns`)

	case "uniteddomains":
		// generated from: providers/dns/uniteddomains/uniteddomains.toml
		ew.writeln(`Configuration for United-Domains.`)
		ew.writeln(`Code:	'uniteddomains'`)
		ew.writeln(`Since:	'v4.29.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "UNITEDDOMAINS_API_KEY":	API key '<prefix>.<secret>' https://www.united-domains.de/help/faq-article/getting-started-with-the-united-domains-dns-api/`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "UNITEDDOMAINS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "UNITEDDOMAINS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "UNITEDDOMAINS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 900)`)
		ew.writeln(`	- "UNITEDDOMAINS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/uniteddomains`)

	case "variomedia":
		// generated from: providers/dns/variomedia/variomedia.toml
		ew.writeln(`Configuration for Variomedia.`)
		ew.writeln(`Code:	'variomedia'`)
		ew.writeln(`Since:	'v4.8.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "VARIOMEDIA_API_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "VARIOMEDIA_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "VARIOMEDIA_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "VARIOMEDIA_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "VARIOMEDIA_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)
		ew.writeln(`	- "VARIOMEDIA_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/variomedia`)

	case "veesp":
		// generated from: providers/dns/veesp/veesp.toml
		ew.writeln(`Configuration for Veesp.`)
		ew.writeln(`Code:	'veesp'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "VEESP_PASSWORD":	Password`)
		ew.writeln(`	- "VEESP_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "VEESP_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "VEESP_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "VEESP_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "VEESP_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/veesp`)

	case "vegadns":
		// generated from: providers/dns/vegadns/vegadns.toml
		ew.writeln(`Configuration for VegaDNS.`)
		ew.writeln(`Code:	'vegadns'`)
		ew.writeln(`Since:	'v1.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "SECRET_VEGADNS_KEY":	API key`)
		ew.writeln(`	- "SECRET_VEGADNS_SECRET":	API secret`)
		ew.writeln(`	- "VEGADNS_URL":	API endpoint URL`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "VEGADNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 60)`)
		ew.writeln(`	- "VEGADNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 720)`)
		ew.writeln(`	- "VEGADNS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 10)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/vegadns`)

	case "vercel":
		// generated from: providers/dns/vercel/vercel.toml
		ew.writeln(`Configuration for Vercel.`)
		ew.writeln(`Code:	'vercel'`)
		ew.writeln(`Since:	'v4.7.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "VERCEL_API_TOKEN":	Authentication token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "VERCEL_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "VERCEL_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 5)`)
		ew.writeln(`	- "VERCEL_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "VERCEL_TEAM_ID":	Team ID (ex: team_xxxxxxxxxxxxxxxxxxxxxxxx)`)
		ew.writeln(`	- "VERCEL_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/vercel`)

	case "versio":
		// generated from: providers/dns/versio/versio.toml
		ew.writeln(`Configuration for Versio.[nl|eu|uk].`)
		ew.writeln(`Code:	'versio'`)
		ew.writeln(`Since:	'v2.7.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "VERSIO_PASSWORD":	Basic authentication password`)
		ew.writeln(`	- "VERSIO_USERNAME":	Basic authentication username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "VERSIO_ENDPOINT":	The endpoint URL of the API Server`)
		ew.writeln(`	- "VERSIO_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "VERSIO_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 5)`)
		ew.writeln(`	- "VERSIO_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "VERSIO_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)
		ew.writeln(`	- "VERSIO_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/versio`)

	case "vinyldns":
		// generated from: providers/dns/vinyldns/vinyldns.toml
		ew.writeln(`Configuration for VinylDNS.`)
		ew.writeln(`Code:	'vinyldns'`)
		ew.writeln(`Since:	'v4.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "VINYLDNS_ACCESS_KEY":	The VinylDNS API key`)
		ew.writeln(`	- "VINYLDNS_HOST":	The VinylDNS API URL`)
		ew.writeln(`	- "VINYLDNS_SECRET_KEY":	The VinylDNS API Secret key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "VINYLDNS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "VINYLDNS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 4)`)
		ew.writeln(`	- "VINYLDNS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "VINYLDNS_QUOTE_VALUE":	Adds quotes around the TXT record value (Default: false)`)
		ew.writeln(`	- "VINYLDNS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 30)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/vinyldns`)

	case "virtualname":
		// generated from: providers/dns/virtualname/virtualname.toml
		ew.writeln(`Configuration for Virtualname.`)
		ew.writeln(`Code:	'virtualname'`)
		ew.writeln(`Since:	'v4.30.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "VIRTUALNAME_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "VIRTUALNAME_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "VIRTUALNAME_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "VIRTUALNAME_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 300)`)
		ew.writeln(`	- "VIRTUALNAME_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/virtualname`)

	case "vkcloud":
		// generated from: providers/dns/vkcloud/vkcloud.toml
		ew.writeln(`Configuration for VK Cloud.`)
		ew.writeln(`Code:	'vkcloud'`)
		ew.writeln(`Since:	'v4.9.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "VK_CLOUD_PASSWORD":	Password for VK Cloud account`)
		ew.writeln(`	- "VK_CLOUD_PROJECT_ID":	String ID of project in VK Cloud`)
		ew.writeln(`	- "VK_CLOUD_USERNAME":	Email of VK Cloud account`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "VK_CLOUD_DNS_ENDPOINT":	URL of DNS API. Defaults to https://mcs.mail.ru/public-dns but can be changed for usage with private clouds`)
		ew.writeln(`	- "VK_CLOUD_DOMAIN_NAME":	Openstack users domain name. Defaults to 'users' but can be changed for usage with private clouds`)
		ew.writeln(`	- "VK_CLOUD_IDENTITY_ENDPOINT":	URL of OpenStack Auth API, Defaults to https://infra.mail.ru:35357/v3/ but can be changed for usage with private clouds`)
		ew.writeln(`	- "VK_CLOUD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "VK_CLOUD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "VK_CLOUD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/vkcloud`)

	case "volcengine":
		// generated from: providers/dns/volcengine/volcengine.toml
		ew.writeln(`Configuration for Volcano Engine/火山引擎.`)
		ew.writeln(`Code:	'volcengine'`)
		ew.writeln(`Since:	'v4.19.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "VOLC_ACCESSKEY":	Access Key ID (AK)`)
		ew.writeln(`	- "VOLC_SECRETKEY":	Secret Access Key (SK)`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "VOLC_HOST":	API host`)
		ew.writeln(`	- "VOLC_HTTP_TIMEOUT":	API request timeout in seconds (Default: 15)`)
		ew.writeln(`	- "VOLC_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "VOLC_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 240)`)
		ew.writeln(`	- "VOLC_REGION":	Region`)
		ew.writeln(`	- "VOLC_SCHEME":	API scheme`)
		ew.writeln(`	- "VOLC_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/volcengine`)

	case "vscale":
		// generated from: providers/dns/vscale/vscale.toml
		ew.writeln(`Configuration for Vscale.`)
		ew.writeln(`Code:	'vscale'`)
		ew.writeln(`Since:	'v2.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "VSCALE_API_TOKEN":	API token`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "VSCALE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "VSCALE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "VSCALE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "VSCALE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/vscale`)

	case "vultr":
		// generated from: providers/dns/vultr/vultr.toml
		ew.writeln(`Configuration for Vultr.`)
		ew.writeln(`Code:	'vultr'`)
		ew.writeln(`Since:	'v0.3.1'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "VULTR_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "VULTR_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "VULTR_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "VULTR_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "VULTR_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/vultr`)

	case "wannafind":
		// generated from: providers/dns/wannafind/wannafind.toml
		ew.writeln(`Configuration for Wannafind.`)
		ew.writeln(`Code:	'wannafind'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "WANNAFIND_API_KEY":	API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "WANNAFIND_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "WANNAFIND_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "WANNAFIND_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "WANNAFIND_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/wannafind`)

	case "webnamesca":
		// generated from: providers/dns/webnamesca/webnamesca.toml
		ew.writeln(`Configuration for webnames.ca.`)
		ew.writeln(`Code:	'webnamesca'`)
		ew.writeln(`Since:	'v4.28.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "WEBNAMESCA_API_KEY":	API key`)
		ew.writeln(`	- "WEBNAMESCA_API_USER":	API username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "WEBNAMESCA_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "WEBNAMESCA_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "WEBNAMESCA_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "WEBNAMESCA_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/webnamesca`)

	case "webnamesru":
		// generated from: providers/dns/webnamesru/webnamesru.toml
		ew.writeln(`Configuration for webnames.ru.`)
		ew.writeln(`Code:	'webnamesru'`)
		ew.writeln(`Since:	'v4.15.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "WEBNAMESRU_API_KEY":	Domain API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "WEBNAMESRU_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "WEBNAMESRU_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "WEBNAMESRU_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/webnamesru`)

	case "websupport":
		// generated from: providers/dns/websupport/websupport.toml
		ew.writeln(`Configuration for Websupport.`)
		ew.writeln(`Code:	'websupport'`)
		ew.writeln(`Since:	'v4.10.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "WEBSUPPORT_API_KEY":	API key`)
		ew.writeln(`	- "WEBSUPPORT_SECRET":	API secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "WEBSUPPORT_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "WEBSUPPORT_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "WEBSUPPORT_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "WEBSUPPORT_SEQUENCE_INTERVAL":	Time between sequential requests in seconds (Default: 60)`)
		ew.writeln(`	- "WEBSUPPORT_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/websupport`)

	case "wedos":
		// generated from: providers/dns/wedos/wedos.toml
		ew.writeln(`Configuration for WEDOS.`)
		ew.writeln(`Code:	'wedos'`)
		ew.writeln(`Since:	'v4.4.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "WEDOS_USERNAME":	Username is the same as for the admin account`)
		ew.writeln(`	- "WEDOS_WAPI_PASSWORD":	Password needs to be generated and IP allowed in the admin interface`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "WEDOS_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "WEDOS_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "WEDOS_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 600)`)
		ew.writeln(`	- "WEDOS_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/wedos`)

	case "westcn":
		// generated from: providers/dns/westcn/westcn.toml
		ew.writeln(`Configuration for West.cn/西部数码.`)
		ew.writeln(`Code:	'westcn'`)
		ew.writeln(`Since:	'v4.21.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "WESTCN_PASSWORD":	API password`)
		ew.writeln(`	- "WESTCN_USERNAME":	Username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "WESTCN_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "WESTCN_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 10)`)
		ew.writeln(`	- "WESTCN_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 120)`)
		ew.writeln(`	- "WESTCN_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/westcn`)

	case "xinnet":
		// generated from: providers/dns/xinnet/xinnet.toml
		ew.writeln(`Configuration for Xinnet.`)
		ew.writeln(`Code:	'xinnet'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "XINNET_AGENT_ID":	Agent ID`)
		ew.writeln(`	- "XINNET_SECRET":	Application secret`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "XINNET_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "XINNET_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "XINNET_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "XINNET_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/xinnet`)

	case "yandex":
		// generated from: providers/dns/yandex/yandex.toml
		ew.writeln(`Configuration for Yandex PDD.`)
		ew.writeln(`Code:	'yandex'`)
		ew.writeln(`Since:	'v3.7.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "YANDEX_PDD_TOKEN":	Basic authentication username`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "YANDEX_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "YANDEX_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "YANDEX_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "YANDEX_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 21600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/yandex`)

	case "yandex360":
		// generated from: providers/dns/yandex360/yandex360.toml
		ew.writeln(`Configuration for Yandex 360.`)
		ew.writeln(`Code:	'yandex360'`)
		ew.writeln(`Since:	'v4.14.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "YANDEX360_OAUTH_TOKEN":	The OAuth Token`)
		ew.writeln(`	- "YANDEX360_ORG_ID":	The organization ID`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "YANDEX360_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "YANDEX360_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "YANDEX360_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "YANDEX360_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 21600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/yandex360`)

	case "yandexcloud":
		// generated from: providers/dns/yandexcloud/yandexcloud.toml
		ew.writeln(`Configuration for Yandex Cloud.`)
		ew.writeln(`Code:	'yandexcloud'`)
		ew.writeln(`Since:	'v4.9.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "YANDEX_CLOUD_FOLDER_ID":	The string id of folder (aka project) in Yandex Cloud`)
		ew.writeln(`	- "YANDEX_CLOUD_IAM_TOKEN":	The base64 encoded json which contains information about iam token of service account with 'dns.admin' permissions`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "YANDEX_CLOUD_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "YANDEX_CLOUD_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "YANDEX_CLOUD_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/yandexcloud`)

	case "zilore":
		// generated from: providers/dns/zilore/zilore.toml
		ew.writeln(`Configuration for Zilore.`)
		ew.writeln(`Code:	'zilore'`)
		ew.writeln(`Since:	'v5.0.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ZILORE_ACCESS_KEY":	Access key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ZILORE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ZILORE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ZILORE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "ZILORE_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 120)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/zilore`)

	case "zoneedit":
		// generated from: providers/dns/zoneedit/zoneedit.toml
		ew.writeln(`Configuration for ZoneEdit.`)
		ew.writeln(`Code:	'zoneedit'`)
		ew.writeln(`Since:	'v4.25.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ZONEEDIT_AUTH_TOKEN":	Authentication token`)
		ew.writeln(`	- "ZONEEDIT_USER":	User ID`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ZONEEDIT_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ZONEEDIT_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ZONEEDIT_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/zoneedit`)

	case "zoneee":
		// generated from: providers/dns/zoneee/zoneee.toml
		ew.writeln(`Configuration for Zone.ee.`)
		ew.writeln(`Code:	'zoneee'`)
		ew.writeln(`Since:	'v2.1.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ZONEEE_API_KEY":	API key`)
		ew.writeln(`	- "ZONEEE_API_USER":	API user`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ZONEEE_ENDPOINT":	API endpoint URL`)
		ew.writeln(`	- "ZONEEE_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ZONEEE_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 5)`)
		ew.writeln(`	- "ZONEEE_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 300)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/zoneee`)

	case "zonomi":
		// generated from: providers/dns/zonomi/zonomi.toml
		ew.writeln(`Configuration for Zonomi.`)
		ew.writeln(`Code:	'zonomi'`)
		ew.writeln(`Since:	'v3.5.0'`)
		ew.writeln()

		ew.writeln(`Credentials:`)
		ew.writeln(`	- "ZONOMI_API_KEY":	User API key`)
		ew.writeln()

		ew.writeln(`Additional Configuration:`)
		ew.writeln(`	- "ZONOMI_HTTP_TIMEOUT":	API request timeout in seconds (Default: 30)`)
		ew.writeln(`	- "ZONOMI_POLLING_INTERVAL":	Time between DNS propagation check in seconds (Default: 2)`)
		ew.writeln(`	- "ZONOMI_PROPAGATION_TIMEOUT":	Maximum waiting time for DNS propagation in seconds (Default: 60)`)
		ew.writeln(`	- "ZONOMI_TTL":	The TTL of the TXT record used for the DNS challenge in seconds (Default: 3600)`)

		ew.writeln()
		ew.writeln(`More information: https://go-acme.github.io/lego/dns/zonomi`)

	default:
		return fmt.Errorf("%q is not yet supported", name)
	}

	if flusher, ok := w.(interface{ Flush() error }); ok {
		return flusher.Flush()
	}
	return nil
}
